import 'dart:io';

import 'package:agoradesk/core/app_shared_prefs.dart';
import 'package:flutter/cupertino.dart';

mixin CountryInfoMixin {
  String get countryCodeMixin {
    final code = Platform.localeName.substring(Platform.localeName.length - 2);
    if (code == 'en') {
      return 'US';
    }
    return code;
  }

  String getCountryName(String code, {bool lowerCase = false}) {
    String? langCode = AppSharedPrefs().locale?.languageCode;
    langCode ??= 'en';
    if (langCode.isEmpty) {
      langCode = 'en';
    }
    try {
      if (lowerCase) {
        return _countryName[langCode][code].toLowerCase();
      }
      return _countryName[langCode][code];
    } catch (e) {
      debugPrint('[getCountryName error] $e');
      return '';
    }
  }

  String getCurrencyName(String code) {
    String? langCode = AppSharedPrefs().locale?.languageCode;

    langCode ??= 'en';
    if (langCode.isEmpty) {
      langCode = 'en';
    }
    try {
      return currencyName[langCode][code];
    } catch (e) {
      debugPrint('[getCurrencyName error] $e');
      return '';
    }
  }

  String getCurrencyNameWithCode(String code) {
    String? langCode = AppSharedPrefs().locale?.languageCode;

    langCode ??= 'en';
    if (langCode.isEmpty) {
      langCode = 'en';
    }
    try {
      return '$code (${currencyName[langCode][code]})';
    } catch (e) {
      debugPrint('[getCurrencyName error] $e');
      return '';
    }
  }

  String getCountryCurrencyCode(String countryCode) {
    try {
      return _countryCurrency[countryCode]!;
    } catch (e) {
      debugPrint('[getCountryCurrencyCode error] $e');
      return '';
    }
  }

  Map<String, dynamic> get currencyName => {
        "en": {
          "AED": "United Arab Emirates Dirham",
          "AFN": "Afghan Afghani",
          "ALL": "Albanian Lek",
          "AMD": "Armenian Dram",
          "ANG": "Netherlands Antillean Guilder",
          "AOA": "Angolan Kwanza",
          "ARS": "Argentine Peso",
          "AUD": "Australian Dollar",
          "AWG": "Aruban Florin",
          "AZN": "Azerbaijani Manat",
          "BAM": "Bosnia-Herzegovina Convertible Mark",
          "BBD": "Barbadian Dollar",
          "BDT": "Bangladeshi Taka",
          "BGN": "Bulgarian Lev",
          "BHD": "Bahraini Dinar",
          "BIF": "Burundian Franc",
          "BMD": "Bermudan Dollar",
          "BND": "Brunei Dollar",
          "BOB": "Bolivian Boliviano",
          "BRL": "Brazilian Real",
          "BSD": "Bahamian Dollar",
          "BTN": "Bhutanese Ngultrum",
          "BWP": "Botswanan Pula",
          "BYN": "Belarusian Ruble",
          "BZD": "Belize Dollar",
          "CAD": "Canadian Dollar",
          "CDF": "Congolese Franc",
          "CHF": "Swiss Franc",
          "CLF": "Chilean Unit of Account (UF)",
          "CLP": "Chilean Peso",
          "CNY": "Chinese Yuan",
          "CNH": "Chinese Yuan",
          "COP": "Colombian Peso",
          "CRC": "Costa Rican Colón",
          "CUC": "Cuban Convertible Peso",
          "CUP": "Cuban Peso",
          "CVE": "Cape Verdean Escudo",
          "CZK": "Czech Koruna",
          "DJF": "Djiboutian Franc",
          "DKK": "Danish Krone",
          "DOP": "Dominican Peso",
          "DZD": "Algerian Dinar",
          "EGP": "Egyptian Pound",
          "ERN": "Eritrean Nakfa",
          "ETB": "Ethiopian Birr",
          "EUR": "Euro",
          "FJD": "Fijian Dollar",
          "FKP": "Falkland Islands Pound",
          "GBP": "British Pound",
          "GEL": "Georgian Lari",
          "GHS": "Ghanaian Cedi",
          "GIP": "Gibraltar Pound",
          "GMD": "Gambian Dalasi",
          "GNF": "Guinean Franc",
          "GTQ": "Guatemalan Quetzal",
          "GYD": "Guyanaese Dollar",
          "HKD": "Hong Kong Dollar",
          "HNL": "Honduran Lempira",
          "HRK": "Croatian Kuna",
          "HTG": "Haitian Gourde",
          "HUF": "Hungarian Forint",
          "IDR": "Indonesian Rupiah",
          "ILS": "Israeli New Shekel",
          "INR": "Indian Rupee",
          "IQD": "Iraqi Dinar",
          "IRR": "Iranian Rial",
          "ISK": "Icelandic Króna",
          "JMD": "Jamaican Dollar",
          "JOD": "Jordanian Dinar",
          "JPY": "Japanese Yen",
          "KES": "Kenyan Shilling",
          "KGS": "Kyrgystani Som",
          "KHR": "Cambodian Riel",
          "KMF": "Comorian Franc",
          "KPW": "North Korean Won",
          "KRW": "South Korean Won",
          "KWD": "Kuwaiti Dinar",
          "KYD": "Cayman Islands Dollar",
          "KZT": "Kazakhstani Tenge",
          "LAK": "Laotian Kip",
          "LBP": "Lebanese Pound",
          "LKR": "Sri Lankan Rupee",
          "LRD": "Liberian Dollar",
          "LSL": "Lesotho Loti",
          "LYD": "Libyan Dinar",
          "MAD": "Moroccan Dirham",
          "MDL": "Moldovan Leu",
          "MGA": "Malagasy Ariary",
          "MKD": "Macedonian Denar",
          "MMK": "Myanmar Kyat",
          "MNT": "Mongolian Tugrik",
          "MOP": "Macanese Pataca",
          "MRO": "Mauritanian Ouguiya",
          "MUR": "Mauritian Rupee",
          "MVR": "Maldivian Rufiyaa",
          "MWK": "Malawian Kwacha",
          "MXN": "Mexican Peso",
          "MYR": "Malaysian Ringgit",
          "MZN": "Mozambican Metical",
          "NAD": "Namibian Dollar",
          "NGN": "Nigerian Naira",
          "NIO": "Nicaraguan Córdoba",
          "NOK": "Norwegian Krone",
          "NPR": "Nepalese Rupee",
          "NZD": "New Zealand Dollar",
          "OMR": "Omani Rial",
          "PAB": "Panamanian Balboa",
          "PEN": "Peruvian Sol",
          "PGK": "Papua New Guinean Kina",
          "PHP": "Philippine Peso",
          "PKR": "Pakistani Rupee",
          "PLN": "Polish Zloty",
          "PYG": "Paraguayan Guarani",
          "QAR": "Qatari Rial",
          "RON": "Romanian Leu",
          "RSD": "Serbian Dinar",
          "RUB": "Russian Ruble",
          "RWF": "Rwandan Franc",
          "SAR": "Saudi Riyal",
          "SBD": "Solomon Islands Dollar",
          "SCR": "Seychellois Rupee",
          "SDG": "Sudanese Pound",
          "SEK": "Swedish Krona",
          "SGD": "Singapore Dollar",
          "SHP": "St. Helena Pound",
          "SLL": "Sierra Leonean Leone",
          "SOS": "Somali Shilling",
          "SRD": "Surinamese Dollar",
          "SSP": "South Sudanese Pound",
          "STD": "São Tomé & Príncipe Dobra",
          "SVC": "Salvadoran Colón",
          "SYP": "Syrian Pound",
          "SZL": "Swazi Lilangeni",
          "THB": "Thai Baht",
          "TJS": "Tajikistani Somoni",
          "TMT": "Turkmenistani Manat",
          "TND": "Tunisian Dinar",
          "TOP": "Tongan Paʻanga",
          "TRY": "Turkish Lira",
          "TTD": "Trinidad & Tobago Dollar",
          "TWD": "New Taiwan Dollar",
          "TZS": "Tanzanian Shilling",
          "UAH": "Ukrainian Hryvnia",
          "UGX": "Ugandan Shilling",
          "USD": "US Dollar",
          "UYU": "Uruguayan Peso",
          "UZS": "Uzbekistani Som",
          "VND": "Vietnamese Dong",
          "VUV": "Vanuatu Vatu",
          "WST": "Samoan Tala",
          "XAF": "Central African CFA Franc",
          "XCD": "East Caribbean Dollar",
          "XOF": "West African CFA Franc",
          "XPF": "CFP Franc",
          "YER": "Yemeni Rial",
          "ZAR": "South African Rand",
          "ZMW": "Zambian Kwacha",
          "ZWL": "Zimbabwean Dollar (2009)",
          "XAU": "Gold Ounce",
          "XAG": "Silver Ounce",
          "XPD": "Palladium Ounce",
          "XPT": "Platinum Ounce",
          "XDR": "SDR (Special Drawing Right)",
          "JEP": "Jersey Pound",
          "GGP": "Guernsey Pound",
          "VES": "Venezuelan Bolívar",
          "IMP": "Isle of Man Pound",
          "BTC": "Bitcoin",
          "ETH": "Ethereum",
          "BCH": "Bitcoin Cash",
          "AEON": "Aeon",
          "XMR": "Monero",
          "USDT": "USD Stablecoins",
          "SC": "Siacoin",
          "XRP": "Ripple",
          "DOGE": "Dogecoin",
          "LTC": "Litecoin",
          "DASH": "Dash",
          "ZEC": "Zcash"
        },
        "es": {
          "AED": "dírham de los Emiratos Árabes Unidos",
          "AFN": "afgani",
          "ALL": "lek",
          "AMD": "dram",
          "ANG": "florín de las Antillas Neerlandesas",
          "AOA": "kuanza",
          "ARS": "peso argentino",
          "AUD": "dólar australiano",
          "AWG": "florín arubeño",
          "AZN": "manat azerí",
          "BAM": "marco convertible de Bosnia-Herzegovina",
          "BBD": "dólar barbadense",
          "BDT": "taka",
          "BGN": "lev búlgaro",
          "BHD": "dinar bahreiní",
          "BIF": "franco burundés",
          "BMD": "dólar de Bermudas",
          "BND": "dólar bruneano",
          "BOB": "boliviano",
          "BRL": "real brasileño",
          "BSD": "dólar bahameño",
          "BTN": "gultrum",
          "BWP": "pula",
          "BYN": "rublo bielorruso",
          "BZD": "dólar beliceño",
          "CAD": "dólar canadiense",
          "CDF": "franco congoleño",
          "CHF": "franco suizo",
          "CLF": "unidad de fomento chilena",
          "CLP": "peso chileno",
          "CNY": "yuan",
          "CNH": "yuan",
          "COP": "peso colombiano",
          "CRC": "colón costarricense",
          "CUC": "peso cubano convertible",
          "CUP": "peso cubano",
          "CVE": "escudo de Cabo Verde",
          "CZK": "corona checa",
          "DJF": "franco yibutiano",
          "DKK": "corona danesa",
          "DOP": "peso dominicano",
          "DZD": "dinar argelino",
          "EGP": "libra egipcia",
          "ERN": "nakfa",
          "ETB": "bir",
          "EUR": "euro",
          "FJD": "dólar fiyiano",
          "FKP": "libra malvinense",
          "GBP": "libra británica",
          "GEL": "lari",
          "GHS": "cedi",
          "GIP": "libra gibraltareña",
          "GMD": "dalasi",
          "GNF": "franco guineano",
          "GTQ": "quetzal guatemalteco",
          "GYD": "dólar guyanés",
          "HKD": "dólar hongkonés",
          "HNL": "lempira hondureño",
          "HRK": "kuna",
          "HTG": "gourde haitiano",
          "HUF": "forinto húngaro",
          "IDR": "rupia indonesia",
          "ILS": "nuevo séquel israelí",
          "INR": "rupia india",
          "IQD": "dinar iraquí",
          "IRR": "rial iraní",
          "ISK": "corona islandesa",
          "JMD": "dólar jamaicano",
          "JOD": "dinar jordano",
          "JPY": "yen",
          "KES": "chelín keniano",
          "KGS": "som",
          "KHR": "riel",
          "KMF": "franco comorense",
          "KPW": "won norcoreano",
          "KRW": "won surcoreano",
          "KWD": "dinar kuwaití",
          "KYD": "dólar de las Islas Caimán",
          "KZT": "tenge kazako",
          "LAK": "kip",
          "LBP": "libra libanesa",
          "LKR": "rupia esrilanquesa",
          "LRD": "dólar liberiano",
          "LSL": "loti lesothense",
          "LYD": "dinar libio",
          "MAD": "dírham marroquí",
          "MDL": "leu moldavo",
          "MGA": "ariari",
          "MKD": "dinar macedonio",
          "MMK": "kiat",
          "MNT": "tugrik",
          "MOP": "pataca de Macao",
          "MRO": "uguiya",
          "MUR": "rupia mauriciana",
          "MVR": "rufiya",
          "MWK": "kwacha malauí",
          "MXN": "peso mexicano",
          "MYR": "ringit",
          "MZN": "metical",
          "NAD": "dólar namibio",
          "NGN": "naira",
          "NIO": "córdoba nicaragüense",
          "NOK": "corona noruega",
          "NPR": "rupia nepalí",
          "NZD": "dólar neozelandés",
          "OMR": "rial omaní",
          "PAB": "balboa panameño",
          "PEN": "sol peruano",
          "PGK": "kina",
          "PHP": "peso filipino",
          "PKR": "rupia pakistaní",
          "PLN": "esloti",
          "PYG": "guaraní paraguayo",
          "QAR": "rial catarí",
          "RON": "leu rumano",
          "RSD": "dinar serbio",
          "RUB": "rublo ruso",
          "RWF": "franco ruandés",
          "SAR": "rial saudí",
          "SBD": "dólar salomonense",
          "SCR": "rupia seychellense",
          "SDG": "libra sudanesa",
          "SEK": "corona sueca",
          "SGD": "dólar singapurense",
          "SHP": "libra de Santa Elena",
          "SLL": "leona",
          "SOS": "chelín somalí",
          "SRD": "dólar surinamés",
          "SSP": "libra sursudanesa",
          "STD": "dobra",
          "SVC": "colón salvadoreño",
          "SYP": "libra siria",
          "SZL": "lilangeni",
          "THB": "bat",
          "TJS": "somoni tayiko",
          "TMT": "manat turcomano",
          "TND": "dinar tunecino",
          "TOP": "paanga",
          "TRY": "lira turca",
          "TTD": "dólar de Trinidad y Tobago",
          "TWD": "nuevo dólar taiwanés",
          "TZS": "chelín tanzano",
          "UAH": "grivna",
          "UGX": "chelín ugandés",
          "USD": "dólar estadounidense",
          "UYU": "peso uruguayo",
          "UZS": "sum",
          "VND": "dong",
          "VUV": "vatu",
          "WST": "tala",
          "XAF": "franco CFA BEAC",
          "XCD": "dólar del Caribe Oriental",
          "XOF": "franco CFA BCEAO",
          "XPF": "franco CFP",
          "YER": "rial yemení",
          "ZAR": "rand",
          "ZMW": "kuacha zambiano",
          "ZWL": "dólar zimbabuense",
          "XAU": "Onza de oro",
          "XAG": "Onza de plata",
          "XPD": "Onza de paladio",
          "XPT": "Onza de platino",
          "XDR": "SDR (Special Drawing Right)",
          "JEP": "Jersey Pound",
          "GGP": "Guernsey Pound",
          "VES": "Venezuelan Bolívar",
          "IMP": "Isle of Man Pound",
          "BTC": "Bitcoin",
          "XMR": "Monero",
          "ETH": "Ethereum",
          "BCH": "Bitcoin Cash",
          "AEON": "Aeon",
          "SC": "Siacoin",
          "USDT": "USD Stablecoins",
          "XRP": "Ripple",
          "DOGE": "Dogecoin",
          "LTC": "Litecoin",
          "DASH": "Dash",
          "ZEC": "Zcash"
        },
        "it": {
          "AED": "dirham degli Emirati Arabi Uniti",
          "AFN": "afghani",
          "ALL": "lek albanese",
          "AMD": "dram armeno",
          "ANG": "fiorino delle Antille olandesi",
          "AOA": "kwanza angolano",
          "ARS": "peso argentino",
          "AUD": "dollaro australiano",
          "AWG": "fiorino di Aruba",
          "AZN": "manat azero",
          "BAM": "marco convertibile della Bosnia-Herzegovina",
          "BBD": "dollaro di Barbados",
          "BDT": "taka bangladese",
          "BGN": "lev bulgaro",
          "BHD": "dinaro del Bahrein",
          "BIF": "franco del Burundi",
          "BMD": "dollaro delle Bermuda",
          "BND": "dollaro del Brunei",
          "BOB": "boliviano",
          "BRL": "real brasiliano",
          "BSD": "dollaro delle Bahamas",
          "BTN": "ngultrum bhutanese",
          "BWP": "pula del Botswana",
          "BYN": "rublo bielorusso",
          "BZD": "dollaro del Belize",
          "CAD": "dollaro canadese",
          "CDF": "franco congolese",
          "CHF": "franco svizzero",
          "CLF": "unidades de fomento chilene",
          "CLP": "peso cileno",
          "CNY": "renminbi cinese",
          "COP": "peso colombiano",
          "CRC": "colón costaricano",
          "CUC": "peso cubano convertibile",
          "CUP": "peso cubano",
          "CVE": "escudo capoverdiano",
          "CZK": "corona ceca",
          "DJF": "franco di Gibuti",
          "DKK": "corona danese",
          "DOP": "peso dominicano",
          "DZD": "dinaro algerino",
          "EGP": "sterlina egiziana",
          "ERN": "nakfa eritreo",
          "ETB": "birr etiope",
          "EUR": "euro",
          "FJD": "dollaro delle Figi",
          "FKP": "sterlina delle Falkland",
          "GBP": "sterlina britannica",
          "GEL": "lari georgiano",
          "GHS": "cedi ghanese",
          "GIP": "sterlina di Gibilterra",
          "GMD": "dalasi gambiano",
          "GNF": "franco della Guinea",
          "GTQ": "quetzal guatemalteco",
          "GYD": "dollaro della Guyana",
          "HKD": "dollaro di Hong Kong",
          "HNL": "lempira honduregna",
          "HRK": "kuna croata",
          "HTG": "gourde haitiano",
          "HUF": "fiorino ungherese",
          "IDR": "rupia indonesiana",
          "ILS": "nuovo siclo israeliano",
          "INR": "rupia indiana",
          "IQD": "dinaro iracheno",
          "IRR": "rial iraniano",
          "ISK": "corona islandese",
          "JMD": "dollaro giamaicano",
          "JOD": "dinaro giordano",
          "JPY": "yen giapponese",
          "KES": "scellino keniota",
          "KGS": "som kirghiso",
          "KHR": "riel cambogiano",
          "KMF": "franco comoriano",
          "KPW": "won nordcoreano",
          "KRW": "won sudcoreano",
          "KWD": "dinaro kuwaitiano",
          "KYD": "dollaro delle Isole Cayman",
          "KZT": "tenge kazako",
          "LAK": "kip laotiano",
          "LBP": "lira libanese",
          "LKR": "rupia di Sri Lanka",
          "LRD": "dollaro liberiano",
          "LSL": "loti del Lesotho",
          "LYD": "dinaro libico",
          "MAD": "dirham marocchino",
          "MDL": "leu moldavo",
          "MGA": "ariary malgascio",
          "MKD": "denar macedone",
          "MMK": "kyat di Myanmar",
          "MNT": "tugrik mongolo",
          "MOP": "pataca di Macao",
          "MRO": "ouguiya della Mauritania",
          "MUR": "rupia mauriziana",
          "MVR": "rufiyaa delle Maldive",
          "MWK": "kwacha malawiano",
          "MXN": "peso messicano",
          "MYR": "ringgit malese",
          "MZN": "metical mozambicano",
          "NAD": "dollaro namibiano",
          "NGN": "naira nigeriana",
          "NIO": "córdoba nicaraguense",
          "NOK": "corona norvegese",
          "NPR": "rupia nepalese",
          "NZD": "dollaro neozelandese",
          "OMR": "rial omanita",
          "PAB": "balboa panamense",
          "PEN": "sol peruviano",
          "PGK": "kina papuana",
          "PHP": "peso filippino",
          "PKR": "rupia pakistana",
          "PLN": "złoty polacco",
          "PYG": "guaraní paraguayano",
          "QAR": "rial qatariano",
          "RON": "leu rumeno",
          "RSD": "dinaro serbo",
          "RUB": "rublo russo",
          "RWF": "franco ruandese",
          "SAR": "riyal saudita",
          "SBD": "dollaro delle Isole Salomone",
          "SCR": "rupia delle Seychelles",
          "SDG": "sterlina sudanese",
          "SEK": "corona svedese",
          "SGD": "dollaro di Singapore",
          "SHP": "sterlina di Sant’Elena",
          "SLL": "leone della Sierra Leone",
          "SOS": "scellino somalo",
          "SRD": "dollaro del Suriname",
          "SSP": "sterlina sud-sudanese",
          "STD": "dobra di Sao Tomé e Principe",
          "SVC": "colón salvadoregno",
          "SYP": "lira siriana",
          "SZL": "lilangeni dello Swaziland",
          "THB": "baht thailandese",
          "TJS": "somoni tagiko",
          "TMT": "manat turkmeno",
          "TND": "dinaro tunisino",
          "TOP": "paʻanga tongano",
          "TRY": "lira turca",
          "TTD": "dollaro di Trinidad e Tobago",
          "TWD": "nuovo dollaro taiwanese",
          "TZS": "scellino della Tanzania",
          "UAH": "grivnia ucraina",
          "UGX": "scellino ugandese",
          "USD": "dollaro statunitense",
          "UYU": "peso uruguayano",
          "UZS": "sum uzbeco",
          "VND": "dong vietnamita",
          "VUV": "vatu di Vanuatu",
          "WST": "tala samoano",
          "XAF": "franco CFA BEAC",
          "XCD": "dollaro dei Caraibi orientali",
          "XOF": "franco CFA BCEAO",
          "XPF": "franco CFP",
          "YER": "riyal yemenita",
          "ZAR": "rand sudafricano",
          "ZMW": "kwacha dello Zambia",
          "ZWL": "dollaro zimbabwiano (2009)",
          "BTC": "Bitcoin",
          "ETH": "Ethereum",
          "BCH": "Bitcoin Cash",
          "AEON": "Aeon",
          "XMR": "Monero",
          "USDT": "USD Stablecoins",
          "SC": "Siacoin",
          "XRP": "Ripple",
          "DOGE": "Dogecoin",
          "LTC": "Litecoin",
          "DASH": "Dash",
          "ZEC": "Zcash"
        },
        "ko": {
          "AED": "아랍에미리트 디르함",
          "AFN": "아프가니스탄 아프가니",
          "ALL": "알바니아 레크",
          "AMD": "아르메니아 드람",
          "ANG": "네덜란드령 안틸레스 휠던",
          "AOA": "앙골라 콴자",
          "ARS": "아르헨티나 페소",
          "AUD": "오스트레일리아 달러",
          "AWG": "아루바 플로린",
          "AZN": "아제르바이잔 마나트",
          "BAM": "보스니아 헤르체고비나 태환 마르카",
          "BBD": "바베이도스 달러",
          "BDT": "방글라데시 타카",
          "BGN": "불가리아 레프",
          "BHD": "바레인 디나르",
          "BIF": "부룬디 프랑",
          "BMD": "버뮤다 달러",
          "BND": "브루나이 달러",
          "BOB": "볼리비아 볼리비아노",
          "BOV": "Bolivian Mvdol (기금부호)",
          "BRL": "브라질 헤알",
          "BSD": "바하마 달러",
          "BTN": "부탄 눌트럼",
          "BWP": "보츠와나 풀라",
          "BYN": "신 벨라루스 루블",
          "BYR": "벨라루스 루블",
          "BZD": "벨리즈 달러",
          "CAD": "캐나다 달러",
          "CDF": "콩고 프랑",
          "CHE": "WIR 유로 (보완화폐)",
          "CHF": "스위스 프랑",
          "CHW": "WIR 프랑 (보완화폐)",
          "CLF": "Unidad de Fomento (기금부호)",
          "CLP": "칠레 페소",
          "CNY": "중국 위안",
          "COP": "콜롬비아 페소",
          "COU": "Unidad de Valor Real (UVR) (기금부호)",
          "CRC": "코스타리카 콜론",
          "CUC": "쿠바 태환 페소",
          "CUP": "쿠바 페소",
          "CVE": "카보베르데 이스쿠두",
          "CZK": "체코 코루나",
          "DJF": "지부티 프랑",
          "DKK": "덴마크 크로네",
          "DOP": "도미니카 페소",
          "DZD": "알제리 디나르",
          "EGP": "이집트 파운드",
          "ERN": "에리트레아 낙파",
          "ETB": "에티오피아 비르",
          "EUR": "유로",
          "FJD": "피지 달러",
          "FKP": "포클랜드 제도 파운드",
          "GBP": "파운드 스털링",
          "GEL": "조지아 라리",
          "GHS": "가나 세디",
          "GIP": "지브롤터 파운드",
          "GMD": "감비아 달라시",
          "GNF": "기니 프랑",
          "GTQ": "과테말라 케찰",
          "GYD": "가이아나 달러",
          "HKD": "홍콩 달러",
          "HNL": "온두라스 렘피라",
          "HRK": "크로아티아 쿠나",
          "HTG": "아이티 구르드",
          "HUF": "헝가리 포린트",
          "IDR": "인도네시아 루피아",
          "ILS": "이스라엘 신 셰켈",
          "INR": "인도 루피",
          "IQD": "이라크 디나르",
          "IRR": "이란 리알",
          "ISK": "아이슬란드 크로나",
          "JMD": "자메이카 달러",
          "JOD": "요르단 디나르",
          "JPY": "일본 엔",
          "KES": "케냐 실링",
          "KGS": "키르기스스탄 솜",
          "KHR": "캄보디아 리엘",
          "KMF": "코모로 프랑",
          "KPW": "조선민주주의인민공화국 원",
          "KRW": "대한민국 원",
          "KWD": "쿠웨이트 디나르",
          "KYD": "케이맨 제도 달러",
          "KZT": "카자흐스탄 텡게",
          "LAK": "라오스 킵",
          "LBP": "레바논 파운드",
          "LKR": "스리랑카 루피",
          "LRD": "라이베리아 달러",
          "LSL": "레소토 로티",
          "LYD": "리비아 디나르",
          "MAD": "모로코 디르함",
          "MDL": "몰도바 레우",
          "MGA": "마다가스카르 아리아리",
          "MKD": "마케도니아 데나르",
          "MMK": "미얀마 짯",
          "MNT": "몽골 투그릭",
          "MOP": "마카오 파타카",
          "MRO": "모리타니 우기야",
          "MUR": "모리셔스 루피",
          "MVR": "몰디브 루피야",
          "MWK": "말라위 콰차",
          "MXN": "멕시코 페소",
          "MXV": "Mexican Unidad de Inversion (UDI) (기금부호)",
          "MYR": "말레이시아 링깃",
          "MZN": "모잠비크 메티칼",
          "NAD": "나미비아 달러",
          "NGN": "나이지리아 나이라",
          "NIO": "니카라과 코르도바",
          "NOK": "노르웨이 크로네",
          "NPR": "네팔 루피",
          "NZD": "뉴질랜드 달러",
          "OMR": "오만 리알",
          "PAB": "파나마 발보아",
          "PEN": "페루 솔",
          "PGK": "파푸아뉴기니 키나",
          "PHP": "필리핀 페소",
          "PKR": "파키스탄 루피",
          "PLN": "폴란드 즈워티",
          "PYG": "파라과이 과라니",
          "QAR": "카타르 리얄",
          "RON": "루마니아 레우",
          "RSD": "세르비아 디나르",
          "RUB": "러시아 루블",
          "RWF": "르완다 프랑",
          "SAR": "사우디아라비아 리얄",
          "SBD": "솔로몬 제도 달러",
          "SCR": "세이셸 루피",
          "SDG": "수단 파운드",
          "SEK": "스웨덴 크로나/크로노르",
          "SGD": "싱가포르 달러",
          "SHP": "세인트헬레나 파운드",
          "SLL": "시에라리온 리온",
          "SOS": "소말리아 실링",
          "SRD": "수리남 달러",
          "SSP": "남수단 파운드",
          "STD": "상투메 프린시페 도브라",
          "SVC": "엘살바도르 콜론",
          "SYP": "시리아 파운드",
          "SZL": "에스와티니 릴랑게니",
          "THB": "태국 밧",
          "TJS": "타지키스탄 소모니",
          "TMT": "투르크메니스탄 마나트",
          "TND": "튀니지 디나르",
          "TOP": "통가 팡가",
          "TRY": "터키 리라",
          "TTD": "트리니다드 토바고 달러",
          "TWD": "신 타이완 달러",
          "TZS": "탄자니아 실링",
          "UAH": "우크라이나 흐리우냐",
          "UGX": "우간다 실링",
          "USD": "미국 달러",
          "USN": "United States dollar (next day) (기금부호)",
          "UYI": "Uruguay peso en Unidades Indexadas (URUIURUI) (기금부호)",
          "UYU": "우루과이 페소",
          "UZS": "우즈베키스탄 숨",
          "VEF": "베네수엘라 볼리바르",
          "VND": "베트남 동",
          "VUV": "바누아투 바투",
          "WST": "사모아 탈라",
          "XAF": "CFA 프랑 BEAC",
          "XAG": "은 (1 트로이 온스)",
          "XAU": "금 (1 트로이 온스)",
          "XBA": "European Composite Unit (EURCO) (채권 시장 단위)",
          "XBB": "European Monetary Unit (E.M.U.-6) (채권 시장 단위)",
          "XBC": "European Unit of Account 9 (E.U.A.-9) (채권 시장 단위)",
          "XBD": "European Unit of Account 17 (E.U.A.-17) (채권 시장 단위)",
          "XCD": "동카리브 달러",
          "XDR": "특별인출권",
          "XOF": "CFA 프랑 BCEAO",
          "XPD": "팔라듐 (1 트로이 온스)",
          "XPF": "CFP 프랑 (franc Pacifique)",
          "XPT": "백금 (1 트로이 온스)",
          "XSU": "SUCRE",
          "XUA": "ADB Unit of Account",
          "XXX": "통화 없음",
          "YER": "예멘 리알",
          "ZAR": "남아프리카 공화국 랜드",
          "ZMW": "잠비아 콰차",
          "ZWL": "짐바브웨 달러 A/10"
        },
        "pt": {
          "AED": "Dirrã dos Emirados Árabes Unidos",
          "AFN": "Afegane afegão",
          "ALL": "Lek albanês",
          "AMD": "Dram armênio",
          "ANG": "Florim das Antilhas Holandesas",
          "AOA": "Kwanza angolano",
          "ARS": "Peso argentino",
          "AUD": "Dólar australiano",
          "AWG": "Florim arubano",
          "AZN": "Manat azeri",
          "BAM": "Marco bósnio-herzegovino conversível",
          "BBD": "Dólar barbadense",
          "BDT": "Taka bengalesa",
          "BGN": "Lev búlgaro",
          "BHD": "Dinar bareinita",
          "BIF": "Franco burundiano",
          "BMD": "Dólar bermudense",
          "BND": "Dólar bruneano",
          "BOB": "Boliviano",
          "BRL": "Real brasileiro",
          "BSD": "Dólar bahamense",
          "BTN": "Ngultrum butanês",
          "BWP": "Pula botsuanesa",
          "BYN": "Rublo bielorrusso",
          "BZD": "Dólar belizenho",
          "CAD": "Dólar canadense",
          "CDF": "Franco congolês",
          "CHF": "Franco suíço",
          "CLF": "Unidades de Fomento chilenas",
          "CLP": "Peso chileno",
          "CNY": "Yuan chinês",
          "CNH": "Yuan chinês",
          "COP": "Peso colombiano",
          "CRC": "Colón costarriquenho",
          "CUC": "Peso cubano conversível",
          "CUP": "Peso cubano",
          "CVE": "Escudo cabo-verdiano",
          "CZK": "Coroa tcheca",
          "DJF": "Franco djibutiense",
          "DKK": "Coroa dinamarquesa",
          "DOP": "Peso dominicano",
          "DZD": "Dinar argelino",
          "EGP": "Libra egípcia",
          "ERN": "Nakfa da Eritreia",
          "ETB": "Birr etíope",
          "EUR": "Euro",
          "FJD": "Dólar fijiano",
          "FKP": "Libra malvinense",
          "GBP": "Libra britânica",
          "GEL": "Lari georgiano",
          "GHS": "Cedi ganês",
          "GIP": "Libra de Gibraltar",
          "GMD": "Dalasi gambiano",
          "GNF": "Franco guineano",
          "GTQ": "Quetzal guatemalense",
          "GYD": "Dólar guianense",
          "HKD": "Dólar de Hong Kong",
          "HNL": "Lempira hondurenha",
          "HRK": "Kuna croata",
          "HTG": "Gourde haitiano",
          "HUF": "Forint húngaro",
          "IDR": "Rupia indonésia",
          "ILS": "Sheqel novo israelita",
          "INR": "Rupia indiana",
          "IQD": "Dinar iraquiano",
          "IRR": "Rial iraniano",
          "ISK": "Coroa islandesa",
          "JMD": "Dólar jamaicano",
          "JOD": "Dinar jordaniano",
          "JPY": "Iene japonês",
          "KES": "Xelim queniano",
          "KGS": "Som quirguiz",
          "KHR": "Riel cambojano",
          "KMF": "Franco comorense",
          "KPW": "Won norte-coreano",
          "KRW": "Won sul-coreano",
          "KWD": "Dinar kuwaitiano",
          "KYD": "Dólar das Ilhas Caiman",
          "KZT": "Tenge cazaque",
          "LAK": "Kip laosiano",
          "LBP": "Libra libanesa",
          "LKR": "Rupia ceilandesa",
          "LRD": "Dólar liberiano",
          "LSL": "Loti do Lesoto",
          "LYD": "Dinar líbio",
          "MAD": "Dirrã marroquino",
          "MDL": "Leu moldávio",
          "MGA": "Ariary malgaxe",
          "MKD": "Dinar macedônio",
          "MMK": "Kyat mianmarense",
          "MNT": "Tugrik mongol",
          "MOP": "Pataca macaense",
          "MRO": "Ouguiya mauritana",
          "MUR": "Rupia mauriciana",
          "MVR": "Rupia maldiva",
          "MWK": "Kwacha malawiana",
          "MXN": "Peso mexicano",
          "MYR": "Ringgit malaio",
          "MZN": "Metical moçambicano",
          "NAD": "Dólar namibiano",
          "NGN": "Naira nigeriana",
          "NIO": "Córdoba nicaraguense",
          "NOK": "Coroa norueguesa",
          "NPR": "Rupia nepalesa",
          "NZD": "Dólar neozelandês",
          "OMR": "Rial omanense",
          "PAB": "Balboa panamenha",
          "PEN": "Sol peruano",
          "PGK": "Kina papuásia",
          "PHP": "Peso filipino",
          "PKR": "Rupia paquistanesa",
          "PLN": "Zloti polonês",
          "PYG": "Guarani paraguaio",
          "QAR": "Rial catariano",
          "RON": "Leu romeno",
          "RSD": "Dinar sérvio",
          "RUB": "Rublo russo",
          "RWF": "Franco ruandês",
          "SAR": "Riyal saudita",
          "SBD": "Dólar das Ilhas Salomão",
          "SCR": "Rupia seichelense",
          "SDG": "Libra sudanesa",
          "SEK": "Coroa sueca",
          "SGD": "Dólar singapuriano",
          "SHP": "Libra de Santa Helena",
          "SLL": "Leone de Serra Leoa",
          "SOS": "Xelim somaliano",
          "SRD": "Dólar surinamês",
          "SSP": "Libra sul-sudanesa",
          "STD": "Dobra de São Tomé e Príncipe",
          "SVC": "Colom salvadorenho",
          "SYP": "Libra síria",
          "SZL": "Lilangeni suazi",
          "THB": "Baht tailandês",
          "TJS": "Somoni tadjique",
          "TMT": "Manat turcomeno",
          "TND": "Dinar tunisiano",
          "TOP": "Paʻanga tonganesa",
          "TRY": "Lira turca",
          "TTD": "Dólar de Trinidad e Tobago",
          "TWD": "Novo dólar taiwanês",
          "TZS": "Xelim tanzaniano",
          "UAH": "Hryvnia ucraniano",
          "UGX": "Xelim ugandense",
          "USD": "Dólar americano",
          "UYU": "Peso uruguaio",
          "UZS": "Som uzbeque",
          "VND": "Dong vietnamita",
          "VUV": "Vatu vanuatuense",
          "WST": "Tala samoano",
          "XAF": "Franco CFA de BEAC",
          "XCD": "Dólar do Caribe Oriental",
          "XOF": "Franco CFA de BCEAO",
          "XPF": "Franco CFP",
          "YER": "Rial iemenita",
          "ZAR": "Rand sul-africano",
          "ZMW": "Kwacha zambiano",
          "ZWL": "Dólar do Zimbábue (2009)",
          "XAU": "Onça de ouro",
          "XAG": "Onça de Prata",
          "XPD": "onça de paládio",
          "XPT": "Onça de platina",
          "XDR": "SDR (Special Drawing Right)",
          "JEP": "Jersey Pound",
          "GGP": "Guernsey Pound",
          "VES": "Venezuelan Bolívar",
          "IMP": "Isle of Man Pound",
          "BTC": "Bitcoin",
          "ETH": "Ethereum",
          "BCH": "Bitcoin Cash",
          "AEON": "Aeon",
          "XMR": "Monero",
          "USDT": "USD Stablecoins",
          "SC": "Siacoin",
          "XRP": "Ripple",
          "DOGE": "Dogecoin",
          "LTC": "Litecoin",
          "DASH": "Dash",
          "ZEC": "Zcash"
        },
        "ru": {
          "AED": "Дирхам ОАЭ",
          "AFN": "Афгани",
          "ALL": "Албанский лек",
          "AMD": "Армянский драм",
          "ANG": "Нидерландский антильский гульден",
          "AOA": "Ангольская кванза",
          "ARS": "Аргентинское песо",
          "AUD": "Австралийский доллар",
          "AWG": "Арубанский флорин",
          "AZN": "Азербайджанский манат",
          "BAM": "Конвертируемая марка Боснии и Герцеговины",
          "BBD": "Барбадосский доллар",
          "BDT": "Бангладешская така",
          "BGN": "Болгарский лев",
          "BHD": "Бахрейнский динар",
          "BIF": "Бурундийский франк",
          "BMD": "Бермудский доллар",
          "BND": "Брунейский доллар",
          "BOB": "Боливийский боливиано",
          "BRL": "Бразильский реал",
          "BSD": "Багамский доллар",
          "BTN": "Бутанский нгултрум",
          "BWP": "Ботсванская пула",
          "BYN": "Белорусский рубль",
          "BZD": "Белизский доллар",
          "CAD": "Канадский доллар",
          "CDF": "Конголезский франк",
          "CHF": "Швейцарский франк",
          "CLF": "Условная расчетная единица Чили",
          "CLP": "Чилийское песо",
          "CNY": "Китайский юань",
          "CNH": "Китайский юань",
          "COP": "Колумбийское песо",
          "CRC": "Костариканский колон",
          "CUC": "Кубинское конвертируемое песо",
          "CUP": "Кубинское песо",
          "CVE": "Эскудо Кабо-Верде",
          "CZK": "Чешская крона",
          "DJF": "Франк Джибути",
          "DKK": "Датская крона",
          "DOP": "Доминиканское песо",
          "DZD": "Алжирский динар",
          "EGP": "Египетский фунт",
          "ERN": "Накфа",
          "ETB": "Эфиопский быр",
          "EUR": "Евро",
          "FJD": "Доллар Фиджи",
          "FKP": "Фунт Фолклендских островов",
          "GBP": "Британский фунт стерлингов",
          "GEL": "Грузинский лари",
          "GHS": "Ганский седи",
          "GIP": "Гибралтарский фунт",
          "GMD": "Гамбийский даласи",
          "GNF": "Гвинейский франк",
          "GTQ": "Гватемальский кетсаль",
          "GYD": "Гайанский доллар",
          "HKD": "Гонконгский доллар",
          "HNL": "Гондурасская лемпира",
          "HRK": "Хорватская куна",
          "HTG": "Гаитянский гурд",
          "HUF": "Венгерский форинт",
          "IDR": "Индонезийская рупия",
          "ILS": "Новый израильский шекель",
          "INR": "Индийская рупия",
          "IQD": "Иракский динар",
          "IRR": "Иранский риал",
          "ISK": "Исландская крона",
          "JMD": "Ямайский доллар",
          "JOD": "Иорданский динар",
          "JPY": "Японская иена",
          "KES": "Кенийский шиллинг",
          "KGS": "Киргизский сом",
          "KHR": "Камбоджийский риель",
          "KMF": "Франк Коморских Островов",
          "KPW": "Северокорейская вона",
          "KRW": "Южнокорейская вона",
          "KWD": "Кувейтский динар",
          "KYD": "Доллар Каймановых островов",
          "KZT": "Казахский тенге",
          "LAK": "Лаосский кип",
          "LBP": "Ливанский фунт",
          "LKR": "Шри-ланкийская рупия",
          "LRD": "Либерийский доллар",
          "LSL": "Лоти",
          "LYD": "Ливийский динар",
          "MAD": "Марокканский дирхам",
          "MDL": "Молдавский лей",
          "MGA": "Малагасийский ариари",
          "MKD": "Македонский денар",
          "MMK": "Мьянманский кьят",
          "MNT": "Монгольский тугрик",
          "MOP": "Патака Макао",
          "MRO": "Мавританская угия",
          "MUR": "Маврикийская рупия",
          "MVR": "Мальдивская руфия",
          "MWK": "Малавийская квача",
          "MXN": "Мексиканское песо",
          "MYR": "Малайзийский ринггит",
          "MZN": "Мозамбикский метикал",
          "NAD": "Доллар Намибии",
          "NGN": "Нигерийская найра",
          "NIO": "Никарагуанская кордоба",
          "NOK": "Норвежская крона",
          "NPR": "Непальская рупия",
          "NZD": "Новозеландский доллар",
          "OMR": "Оманский риал",
          "PAB": "Панамское бальбоа",
          "PEN": "Перуанский соль",
          "PGK": "Кина Папуа – Новой Гвинеи",
          "PHP": "Филиппинское песо",
          "PKR": "Пакистанская рупия",
          "PLN": "Польский злотый",
          "PYG": "Парагвайский гуарани",
          "QAR": "Катарский риал",
          "RON": "Румынский лей",
          "RSD": "Сербский динар",
          "RUB": "Российский рубль",
          "RWF": "Франк Руанды",
          "SAR": "Саудовский риял",
          "SBD": "Доллар Соломоновых Островов",
          "SCR": "Сейшельская рупия",
          "SDG": "Суданский фунт",
          "SEK": "Шведская крона",
          "SGD": "Сингапурский доллар",
          "SHP": "Фунт острова Святой Елены",
          "SLL": "Леоне",
          "SOS": "Сомалийский шиллинг",
          "SRD": "Суринамский доллар",
          "SSP": "Южносуданский фунт",
          "STD": "Добра Сан-Томе и Принсипи",
          "SVC": "Сальвадорский колон",
          "SYP": "Сирийский фунт",
          "SZL": "Свазилендский лилангени",
          "THB": "Таиландский бат",
          "TJS": "Таджикский сомони",
          "TMT": "Новый туркменский манат",
          "TND": "Тунисский динар",
          "TOP": "Тонганская паанга",
          "TRY": "Турецкая лира",
          "TTD": "Доллар Тринидада и Тобаго",
          "TWD": "Новый тайваньский доллар",
          "TZS": "Танзанийский шиллинг",
          "UAH": "Украинская гривна",
          "UGX": "Угандийский шиллинг",
          "USD": "Доллар США",
          "UYU": "Уругвайское песо",
          "UZS": "Узбекский сум",
          "VND": "Вьетнамский донг",
          "VUV": "Вату Вануату",
          "WST": "Самоанская тала",
          "XAF": "Франк КФА ВЕАС",
          "XCD": "Восточно-карибский доллар",
          "XOF": "Франк КФА ВСЕАО",
          "XPF": "Французский тихоокеанский франк",
          "YER": "Йеменский риал",
          "ZAR": "Южноафриканский рэнд",
          "ZMW": "Замбийская квача",
          "ZWL": "Доллар Зимбабве (2009)",
          "XAU": "Золотая унция",
          "XAG": "Серебряная унция",
          "XPD": "Палладиевая унция",
          "XPT": "Платиновая унция",
          "XDR": "SDR (Special Drawing Right)",
          "JEP": "Jersey Pound",
          "GGP": "Guernsey Pound",
          "VES": "Venezuelan Bolívar",
          "IMP": "Isle of Man Pound",
          "BTC": "Bitcoin",
          "ETH": "Ethereum",
          "BCH": "Bitcoin Cash",
          "AEON": "Aeon",
          "XMR": "Monero",
          "USDT": "USD Стейблкойн",
          "SC": "Siacoin",
          "XRP": "Ripple",
          "DOGE": "Dogecoin",
          "LTC": "Litecoin",
          "DASH": "Dash",
          "ZEC": "Zcash"
        },
        "zh": {
          "AED": "阿联酋迪拉姆",
          "AFN": "阿富汗尼",
          "ALL": "阿尔巴尼亚列克",
          "AMD": "亚美尼亚德拉姆",
          "ANG": "荷属安的列斯盾",
          "AOA": "安哥拉宽扎",
          "ARS": "阿根廷比索",
          "AUD": "澳大利亚元",
          "AWG": "阿鲁巴弗罗林",
          "AZN": "阿塞拜疆马纳特",
          "BAM": "波斯尼亚-黑塞哥维那可兑换马克",
          "BBD": "巴巴多斯元",
          "BDT": "孟加拉塔卡",
          "BGN": "保加利亚列弗",
          "BHD": "巴林第纳尔",
          "BIF": "布隆迪法郎",
          "BMD": "百慕大元",
          "BND": "文莱元",
          "BOB": "玻利维亚诺",
          "BRL": "巴西雷亚尔",
          "BSD": "巴哈马元",
          "BTN": "不丹努尔特鲁姆",
          "BWP": "博茨瓦纳普拉",
          "BYN": "白俄罗斯卢布",
          "BZD": "伯利兹元",
          "CAD": "加拿大元",
          "CDF": "刚果法郎",
          "CHF": "瑞士法郎",
          "CLF": "智利（资金）",
          "CLP": "智利比索",
          "CNY": "人民币",
          "CNH": "人民币",
          "COP": "哥伦比亚比索",
          "CRC": "哥斯达黎加科朗",
          "CUC": "古巴可兑换比索",
          "CUP": "古巴比索",
          "CVE": "佛得角埃斯库多",
          "CZK": "捷克克朗",
          "DJF": "吉布提法郎",
          "DKK": "丹麦克朗",
          "DOP": "多米尼加比索",
          "DZD": "阿尔及利亚第纳尔",
          "EGP": "埃及镑",
          "ERN": "厄立特里亚纳克法",
          "ETB": "埃塞俄比亚比尔",
          "EUR": "欧元",
          "FJD": "斐济元",
          "FKP": "福克兰群岛镑",
          "GBP": "英镑",
          "GEL": "格鲁吉亚拉里",
          "GHS": "加纳塞地",
          "GIP": "直布罗陀镑",
          "GMD": "冈比亚达拉西",
          "GNF": "几内亚法郎",
          "GTQ": "危地马拉格查尔",
          "GYD": "圭亚那元",
          "HKD": "港元",
          "HNL": "洪都拉斯伦皮拉",
          "HRK": "克罗地亚库纳",
          "HTG": "海地古德",
          "HUF": "匈牙利福林",
          "IDR": "印度尼西亚盾",
          "ILS": "以色列新谢克尔",
          "INR": "印度卢比",
          "IQD": "伊拉克第纳尔",
          "IRR": "伊朗里亚尔",
          "ISK": "冰岛克朗",
          "JMD": "牙买加元",
          "JOD": "约旦第纳尔",
          "JPY": "日元",
          "KES": "肯尼亚先令",
          "KGS": "吉尔吉斯斯坦索姆",
          "KHR": "柬埔寨瑞尔",
          "KMF": "科摩罗法郎",
          "KPW": "朝鲜元",
          "KRW": "韩元",
          "KWD": "科威特第纳尔",
          "KYD": "开曼元",
          "KZT": "哈萨克斯坦坚戈",
          "LAK": "老挝基普",
          "LBP": "黎巴嫩镑",
          "LKR": "斯里兰卡卢比",
          "LRD": "利比里亚元",
          "LSL": "莱索托洛蒂",
          "LYD": "利比亚第纳尔",
          "MAD": "摩洛哥迪拉姆",
          "MDL": "摩尔多瓦列伊",
          "MGA": "马达加斯加阿里亚里",
          "MKD": "马其顿第纳尔",
          "MMK": "缅甸元",
          "MNT": "蒙古图格里克",
          "MOP": "澳门币",
          "MRO": "毛里塔尼亚乌吉亚",
          "MUR": "毛里求斯卢比",
          "MVR": "马尔代夫卢菲亚",
          "MWK": "马拉维克瓦查",
          "MXN": "墨西哥比索",
          "MYR": "马来西亚林吉特",
          "MZN": "莫桑比克美提卡",
          "NAD": "纳米比亚元",
          "NGN": "尼日利亚奈拉",
          "NIO": "尼加拉瓜科多巴",
          "NOK": "挪威克朗",
          "NPR": "尼泊尔卢比",
          "NZD": "新西兰元",
          "OMR": "阿曼里亚尔",
          "PAB": "巴拿马巴波亚",
          "PEN": "秘鲁索尔",
          "PGK": "巴布亚新几内亚基那",
          "PHP": "菲律宾比索",
          "PKR": "巴基斯坦卢比",
          "PLN": "波兰兹罗提",
          "PYG": "巴拉圭瓜拉尼",
          "QAR": "卡塔尔里亚尔",
          "RON": "罗马尼亚列伊",
          "RSD": "塞尔维亚第纳尔",
          "RUB": "俄罗斯卢布",
          "RWF": "卢旺达法郎",
          "SAR": "沙特里亚尔",
          "SBD": "所罗门群岛元",
          "SCR": "塞舌尔卢比",
          "SDG": "苏丹镑",
          "SEK": "瑞典克朗",
          "SGD": "新加坡元",
          "SHP": "圣赫勒拿群岛磅",
          "SLL": "塞拉利昂利昂",
          "SOS": "索马里先令",
          "SRD": "苏里南元",
          "SSP": "南苏丹镑",
          "STD": "圣多美和普林西比多布拉",
          "SVC": "萨尔瓦多科朗",
          "SYP": "叙利亚镑",
          "SZL": "斯威士兰里兰吉尼",
          "THB": "泰铢",
          "TJS": "塔吉克斯坦索莫尼",
          "TMT": "土库曼斯坦马纳特",
          "TND": "突尼斯第纳尔",
          "TOP": "汤加潘加",
          "TRY": "土耳其里拉",
          "TTD": "特立尼达和多巴哥元",
          "TWD": "新台币",
          "TZS": "坦桑尼亚先令",
          "UAH": "乌克兰格里夫纳",
          "UGX": "乌干达先令",
          "USD": "美元",
          "UYU": "乌拉圭比索",
          "UZS": "乌兹别克斯坦苏姆",
          "VND": "越南盾",
          "VUV": "瓦努阿图瓦图",
          "WST": "萨摩亚塔拉",
          "XAF": "中非法郎",
          "XCD": "东加勒比元",
          "XOF": "西非法郎",
          "XPF": "太平洋法郎",
          "YER": "也门里亚尔",
          "ZAR": "南非兰特",
          "ZMW": "赞比亚克瓦查",
          "ZWL": "津巴布韦元 (2009)",
          "XAU": "金盎司",
          "XAG": "银盎司",
          "XPD": "钯盎司",
          "XPT": "白金盎司",
          "XDR": "SDR (Special Drawing Right)",
          "JEP": "Jersey Pound",
          "GGP": "Guernsey Pound",
          "VES": "Venezuelan Bolívar",
          "IMP": "Isle of Man Pound",
          "BTC": "Bitcoin",
          "ETH": "Ethereum",
          "BCH": "Bitcoin Cash",
          "AEON": "Aeon",
          "XMR": "Monero",
          "USDT": "USD 稳定币",
          "SC": "Siacoin",
          "XRP": "Ripple",
          "DOGE": "Dogecoin",
          "LTC": "Litecoin",
          "DASH": "Dash",
          "ZEC": "Zcash"
        },
      };
  final Map<String, dynamic> _countryName = {
    "en": {
      "ANY": "Any country",
      "AF": "Afghanistan",
      "AL": "Albania",
      "DZ": "Algeria",
      "AS": "American Samoa",
      "AD": "Andorra",
      "AO": "Angola",
      "AI": "Anguilla",
      "AQ": "Antarctica",
      "AG": "Antigua and Barbuda",
      "AR": "Argentina",
      "AM": "Armenia",
      "AW": "Aruba",
      "AU": "Australia",
      "AT": "Austria",
      "AZ": "Azerbaijan",
      "BS": "Bahamas",
      "BH": "Bahrain",
      "BD": "Bangladesh",
      "BB": "Barbados",
      "BY": "Belarus",
      "BE": "Belgium",
      "BZ": "Belize",
      "BJ": "Benin",
      "BM": "Bermuda",
      "BT": "Bhutan",
      "BO": "Bolivia",
      "BA": "Bosnia and Herzegovina",
      "BW": "Botswana",
      "BV": "Bouvet Island",
      "BR": "Brazil",
      "IO": "British Indian Ocean Territory",
      "BN": "Brunei Darussalam",
      "BG": "Bulgaria",
      "BF": "Burkina Faso",
      "BI": "Burundi",
      "KH": "Cambodia",
      "CM": "Cameroon",
      "CA": "Canada",
      "CV": "Cape Verde",
      "KY": "Cayman Islands",
      "CF": "Central African Republic",
      "TD": "Chad",
      "CL": "Chile",
      "CN": "China",
      "CX": "Christmas Island",
      "CC": "Cocos Islands",
      "CO": "Colombia",
      "KM": "Comoros",
      "CG": "Congo",
      "CD": "Congo",
      "CK": "Cook Islands",
      "CR": "Costa Rica",
      "CI": "Cote D'Ivoire",
      "HR": "Croatia",
      "CU": "Cuba",
      "CY": "Cyprus",
      "CZ": "Czech Republic",
      "DK": "Denmark",
      "DJ": "Djibouti",
      "DM": "Dominica",
      "DO": "Dominican Republic",
      "EC": "Ecuador",
      "EG": "Egypt",
      "SV": "El Salvador",
      "GQ": "Equatorial Guinea",
      "ER": "Eritrea",
      "EE": "Estonia",
      "ET": "Ethiopia",
      "FK": "Falkland Islands",
      "FO": "Faroe Islands",
      "FJ": "Fiji",
      "FI": "Finland",
      "FR": "France",
      "GF": "French Guiana",
      "PF": "French Polynesia",
      "TF": "French Southern Territories",
      "GA": "Gabon",
      "GM": "Gambia",
      "GE": "Georgia",
      "DE": "Germany",
      "GH": "Ghana",
      "GI": "Gibraltar",
      "GR": "Greece",
      "GL": "Greenland",
      "GD": "Grenada",
      "GP": "Guadeloupe",
      "GU": "Guam",
      "GT": "Guatemala",
      "GN": "Guinea",
      "GW": "Guinea-Bissau",
      "GY": "Guyana",
      "HT": "Haiti",
      "HM": "Heard Island and Mcdonald Islands",
      "VA": "Vatican City",
      "HN": "Honduras",
      "HK": "Hong Kong",
      "HU": "Hungary",
      "IS": "Iceland",
      "IN": "India",
      "ID": "Indonesia",
      "IR": "Iran",
      "IQ": "Iraq",
      "IE": "Ireland",
      "IL": "Israel",
      "IT": "Italy",
      "JM": "Jamaica",
      "JP": "Japan",
      "JO": "Jordan",
      "KZ": "Kazakhstan",
      "KE": "Kenya",
      "KI": "Kiribati",
      "KP": "North Korea",
      "KR": "South Korea",
      "KV": "Kosovo",
      "KW": "Kuwait",
      "KG": "Kyrgyzstan",
      "LA": "Lao",
      "LV": "Latvia",
      "LB": "Lebanon",
      "LS": "Lesotho",
      "LR": "Liberia",
      "LY": "Libya",
      "LI": "Liechtenstein",
      "LT": "Lithuania",
      "LU": "Luxembourg",
      "MO": "Macao",
      "MK": "Macedonia",
      "MG": "Madagascar",
      "MW": "Malawi",
      "MY": "Malaysia",
      "MV": "Maldives",
      "ML": "Mali",
      "MT": "Malta",
      "MH": "Marshall Islands",
      "MQ": "Martinique",
      "MR": "Mauritania",
      "MU": "Mauritius",
      "YT": "Mayotte",
      "MX": "Mexico",
      "FM": "Micronesia",
      "MD": "Moldova",
      "MC": "Monaco",
      "MN": "Mongolia",
      "MS": "Montserrat",
      "MA": "Morocco",
      "MZ": "Mozambique",
      "MM": "Myanmar",
      "NA": "Namibia",
      "NR": "Nauru",
      "NP": "Nepal",
      "NL": "Netherlands",
      "NC": "New Caledonia",
      "NZ": "New Zealand",
      "NI": "Nicaragua",
      "NE": "Niger",
      "NG": "Nigeria",
      "NU": "Niue",
      "NF": "Norfolk Island",
      "MP": "Northern Mariana Islands",
      "NO": "Norway",
      "OM": "Oman",
      "PK": "Pakistan",
      "PW": "Palau",
      "PS": "Palestinian Territory",
      "PA": "Panama",
      "PG": "Papua New Guinea",
      "PY": "Paraguay",
      "PE": "Peru",
      "PH": "Philippines",
      "PN": "Pitcairn",
      "PL": "Poland",
      "PT": "Portugal",
      "PR": "Puerto Rico",
      "QA": "Qatar",
      "RE": "Reunion",
      "RO": "Romania",
      "RU": "Russian Federation",
      "RW": "Rwanda",
      "SH": "Saint Helena",
      "KN": "Saint Kitts and Nevis",
      "LC": "Saint Lucia",
      "PM": "Saint Pierre and Miquelon",
      "VC": "Saint Vincent and the Grenadines",
      "WS": "Samoa",
      "SM": "San Marino",
      "ST": "Sao Tome and Principe",
      "SA": "Saudi Arabia",
      "SN": "Senegal",
      "SC": "Seychelles",
      "SL": "Sierra Leone",
      "SG": "Singapore",
      "SK": "Slovakia",
      "SI": "Slovenia",
      "SB": "Solomon Islands",
      "SO": "Somalia",
      "ZA": "South Africa",
      "GS": "South Georgia and the South Sandwich Islands",
      "ES": "Spain",
      "LK": "Sri Lanka",
      "SD": "Sudan",
      "SR": "Suriname",
      "SJ": "Svalbard and Jan Mayen",
      "SZ": "Swaziland",
      "SE": "Sweden",
      "CH": "Switzerland",
      "SY": "Syria",
      "TW": "Taiwan",
      "TJ": "Tajikistan",
      "TZ": "Tanzania",
      "TH": "Thailand",
      "TL": "Timor-Leste",
      "TG": "Togo",
      "TK": "Tokelau",
      "TO": "Tonga",
      "TT": "Trinidad and Tobago",
      "TN": "Tunisia",
      "TR": "Turkey",
      "TM": "Turkmenistan",
      "TC": "Turks and Caicos Islands",
      "TV": "Tuvalu",
      "UG": "Uganda",
      "UA": "Ukraine",
      "AE": "United Arab Emirates",
      "GB": "United Kingdom",
      "US": "United States of America",
      "UM": "United States Minor Outlying Islands",
      "UY": "Uruguay",
      "UZ": "Uzbekistan",
      "VU": "Vanuatu",
      "VE": "Venezuela",
      "VN": "Viet Nam",
      "VG": "British Virgin Islands",
      "VI": "US Virgin Islands",
      "WF": "Wallis and Futuna",
      "EH": "Western Sahara",
      "YE": "Yemen",
      "ZM": "Zambia",
      "ZW": "Zimbabwe",
      "AX": "Åland Islands",
      "BQ": "Bonaire",
      "CW": "Curaçao",
      "GG": "Guernsey",
      "IM": "Isle of Man",
      "JE": "Jersey",
      "ME": "Montenegro",
      "BL": "Saint Barthélemy",
      "MF": "Saint Martin",
      "RS": "Serbia",
      "SX": "Sint Maarten",
      "SS": "South Sudan"
    },
    "es": {
      "AF": "Afganistán",
      "AL": "Albania",
      "DZ": "Argelia",
      "AS": "Samoa Americana",
      "AD": "Andorra",
      "AO": "Angola",
      "AI": "Anguila",
      "AQ": "Antártida",
      "AG": "Antigua y Barbuda",
      "AR": "Argentina",
      "AM": "Armenia",
      "AW": "Aruba",
      "AU": "Australia",
      "AT": "Austria",
      "AZ": "Azerbaiyán",
      "BS": "Bahamas",
      "BH": "Bahrein",
      "BD": "Bangladesh",
      "BB": "Barbados",
      "BY": "Belarús",
      "BE": "Bélgica",
      "BZ": "Belice",
      "BJ": "Benin",
      "BM": "Bermudas",
      "BT": "Bhután",
      "BO": "Bolivia",
      "BA": "Bosnia y Herzegovina",
      "BW": "Botswana",
      "BV": "Isla Bouvet",
      "BR": "Brasil",
      "IO": "Territorio Británico del Océano Índico",
      "BN": "Brunei Darussalam",
      "BG": "Bulgaria",
      "BF": "Burkina Faso",
      "BI": "Burundi",
      "KH": "Camboya",
      "CM": "Camerún",
      "CA": "Canadá",
      "CV": "Cabo Verde",
      "KY": "Islas Caimán",
      "CF": "República Centroafricana",
      "TD": "Chad",
      "CL": "Chile",
      "CN": "China",
      "CX": "Isla de Navidad",
      "CC": "Islas Cocos (Keeling)",
      "CO": "Colombia",
      "KM": "Comoras",
      "CG": "Congo",
      "CD": "Congo (República Democrática del)",
      "CK": "Islas Cook",
      "CR": "Costa Rica",
      "CI": "Costa de Marfil",
      "HR": "Croacia",
      "CU": "Cuba",
      "CY": "Chipre",
      "CZ": "República Checa",
      "DK": "Dinamarca",
      "DJ": "Djibouti",
      "DM": "Dominica",
      "DO": "República Dominicana",
      "EC": "Ecuador",
      "EG": "Egipto",
      "SV": "El Salvador",
      "GQ": "Guinea Ecuatorial",
      "ER": "Eritrea",
      "EE": "Estonia",
      "ET": "Etiopía",
      "FK": "Islas Malvinas",
      "FO": "Islas Feroe",
      "FJ": "Fiji",
      "FI": "Finlandia",
      "FR": "Francia",
      "GF": "Guayana Francesa",
      "PF": "Polinesia Francesa",
      "TF": "Tierras Australes Francesas",
      "GA": "Gabón",
      "GM": "Gambia",
      "GE": "Georgia",
      "DE": "Alemania",
      "GH": "Ghana",
      "GI": "Gibraltar",
      "GR": "Grecia",
      "GL": "Groenlandia",
      "GD": "Granada",
      "GP": "Guadeloupe",
      "GU": "Guam",
      "GT": "Guatemala",
      "GN": "Guinea",
      "GW": "Guinea Bissau",
      "GY": "Guyana",
      "HT": "Haití",
      "HM": "Heard e Islas McDonald",
      "VA": "Santa Sede",
      "HN": "Honduras",
      "HK": "Hong Kong",
      "HU": "Hungría",
      "IS": "Islandia",
      "IN": "India",
      "ID": "Indonesia",
      "IR": "Irán (República Islámica de)",
      "IQ": "Iraq",
      "IE": "Irlanda",
      "IL": "Israel",
      "IT": "Italia",
      "JM": "Jamaica",
      "JP": "Japón",
      "JO": "Jordania",
      "KZ": "Kazajstán",
      "KE": "Kenya",
      "KI": "Kiribati",
      "KP": "República Popular Democrática de Corea",
      "KR": "República de Corea",
      "KV": "Kosovo",
      "KW": "Kuwait",
      "KG": "Kirguistán",
      "LA": "República Democrática Popular de Lao",
      "LV": "Letonia",
      "LB": "Líbano",
      "LS": "Lesotho",
      "LR": "Liberia",
      "LY": "Libia",
      "LI": "Liechtenstein",
      "LT": "Lituania",
      "LU": "Luxemburgo",
      "MO": "Macao",
      "MK": "Macedonia",
      "MG": "Madagascar",
      "MW": "Malawi",
      "MY": "Malasia",
      "MV": "Maldivas",
      "ML": "Malí",
      "MT": "Malta",
      "MH": "Islas Marshall",
      "MQ": "Martinique",
      "MR": "Mauritania",
      "MU": "Mauricio",
      "YT": "Mayotte",
      "MX": "México",
      "FM": "Micronesia",
      "MD": "Moldavia",
      "MC": "Mónaco",
      "MN": "Mongolia",
      "MS": "Montserrat",
      "MA": "Marruecos",
      "MZ": "Mozambique",
      "MM": "Myanmar",
      "NA": "Namibia",
      "NR": "Nauru",
      "NP": "Nepal",
      "NL": "Países Bajos",
      "NC": "Nueva Caledonia",
      "NZ": "Nueva Zelanda",
      "NI": "Nicaragua",
      "NE": "Níger",
      "NG": "Nigeria",
      "NU": "Niue",
      "NF": "Isla Norfolk",
      "MP": "Isla Marianas del Norte",
      "NO": "Noruega",
      "OM": "Omán",
      "PK": "Pakistán",
      "PW": "Palau",
      "PS": "Palestina",
      "PA": "Panamá",
      "PG": "Papua Nueva Guinea",
      "PY": "Paraguay",
      "PE": "Perú",
      "PH": "Filipinas",
      "PN": "Pitcairn",
      "PL": "Polonia",
      "PT": "Portugal",
      "PR": "Puerto Rico",
      "QA": "Qatar",
      "RE": "Reunión",
      "RO": "Rumania",
      "RU": "Rusia",
      "RW": "Rwanda",
      "SH": "Santa Helena, Ascensión y Tristán de Acuña",
      "KN": "Saint Kitts y Nevis",
      "LC": "Santa Lucía",
      "PM": "San Pedro y Miquelón",
      "VC": "San Vicente y las Granadinas",
      "WS": "Samoa",
      "SM": "San Marino",
      "ST": "Santo Tomé y Príncipe",
      "SA": "Arabia Saudita",
      "SN": "Senegal",
      "SC": "Seychelles",
      "SL": "Sierra Leona",
      "SG": "Singapur",
      "SK": "Eslovaquia",
      "SI": "Eslovenia",
      "SB": "Islas Salomón",
      "SO": "Somalia",
      "ZA": "Sudáfrica",
      "GS": "Georgia del Sur y las Islas Sandwich del Sur",
      "ES": "España",
      "LK": "Sri Lanka",
      "SD": "Sudan",
      "SR": "Suriname",
      "SJ": "Svalbard y Jan Mayen",
      "SZ": "Swazilandia",
      "SE": "Suecia",
      "CH": "Suiza",
      "SY": "República Árabe Siria",
      "TW": "Taiwán",
      "TJ": "Tayikistán",
      "TZ": "Tanzania",
      "TH": "Tailandia",
      "TL": "Timor-Leste",
      "TG": "Togo",
      "TK": "Tokelau",
      "TO": "Tonga",
      "TT": "Trinidad y Tobago",
      "TN": "Túnez",
      "TR": "Turquía",
      "TM": "Turkmenistán",
      "TC": "Islas Turcas y Caicos",
      "TV": "Tuvalu",
      "UG": "Uganda",
      "UA": "Ucrania",
      "AE": "Emiratos Árabes Unidos",
      "GB": "Reino Unido",
      "US": "Estados Unidos",
      "UM": "Islas Ultramarinas Menores de los Estados Unidos",
      "UY": "Uruguay",
      "UZ": "Uzbekistán",
      "VU": "Vanuatu",
      "VE": "Venezuela",
      "VN": "Vietnam",
      "VG": "Islas Vírgenes británicas",
      "VI": "Islas Vírgenes de los Estados Unidos",
      "WF": "Wallis y Futuna",
      "EH": "Sahara Occidental",
      "YE": "Yemen",
      "ZM": "Zambia",
      "ZW": "Zimbabwe",
      "AX": "Islas Åland",
      "BQ": "Bonaire, San Eustaquio y Saba",
      "CW": "Curaçao",
      "GG": "Guernsey",
      "IM": "Isla de Man",
      "JE": "Jersey",
      "ME": "Montenegro",
      "BL": "Saint Barthélemy",
      "MF": "Saint Martin (francesa)",
      "RS": "Serbia",
      "SX": "Sint Maarten (neerlandesa)",
      "SS": "Sudán del Sur"
    },
    "it": {
      "AD": "Andorra",
      "AE": "Emirati Arabi Uniti",
      "AF": "Afghanistan",
      "AG": "Antigua e Barbuda",
      "AI": "Anguilla",
      "AL": "Albania",
      "AM": "Armenia",
      "AO": "Angola",
      "AQ": "Antartide",
      "AR": "Argentina",
      "AS": "Samoa Americane",
      "AT": "Austria",
      "AU": "Australia",
      "AW": "Aruba",
      "AX": "Isole Åland",
      "AZ": "Azerbaigian",
      "BA": "Bosnia ed Erzegovina",
      "BB": "Barbados",
      "BD": "Bangladesh",
      "BE": "Belgio",
      "BF": "Burkina Faso",
      "BG": "Bulgaria",
      "BH": "Bahrain",
      "BI": "Burundi",
      "BJ": "Benin",
      "BL": "Saint-Barthélemy",
      "BM": "Bermuda",
      "BN": "Brunei",
      "BO": "Bolivia",
      "BQ": "Isole BES",
      "BR": "Brasile",
      "BS": "Bahamas",
      "BT": "Bhutan",
      "BV": "Isola Bouvet",
      "BW": "Botswana",
      "BY": "Bielorussia",
      "BZ": "Belize",
      "CA": "Canada",
      "CC": "Isole Cocos e Keeling",
      "CD": "Repubblica Democratica del Congo",
      "CF": "Repubblica Centrafricana",
      "CG": "Repubblica del Congo",
      "CH": "Svizzera",
      "CI": "Costa d'Avorio",
      "CK": "Isole Cook",
      "CL": "Cile",
      "CM": "Camerun",
      "CN": "Cina",
      "CO": "Colombia",
      "CR": "Costa Rica",
      "CU": "Cuba",
      "CV": "Capo Verde",
      "CW": "Curaçao",
      "CX": "Isola del Natale",
      "CY": "Cipro",
      "CZ": "Repubblica Ceca",
      "DE": "Germania",
      "DJ": "Gibuti",
      "DK": "Danimarca",
      "DM": "Dominica",
      "DO": "Repubblica Dominicana",
      "DZ": "Algeria",
      "EC": "Ecuador",
      "EE": "Estonia",
      "EG": "Egitto",
      "EH": "Sahara Occidentale",
      "ER": "Eritrea",
      "ES": "Spagna",
      "ET": "Etiopia",
      "FI": "Finlandia",
      "FJ": "Figi",
      "FK": "Isole Falkland",
      "FM": "Stati Federati di Micronesia",
      "FO": "Isole Fær Øer",
      "FR": "Francia",
      "GA": "Gabon",
      "GB": "Regno Unito",
      "GD": "Grenada",
      "GE": "Georgia",
      "GF": "Guyana Francese",
      "GG": "Guernsey",
      "GH": "Ghana",
      "GI": "Gibilterra",
      "GL": "Groenlandia",
      "GM": "Gambia",
      "GN": "Guinea",
      "GP": "Guadalupa",
      "GQ": "Guinea Equatoriale",
      "GR": "Grecia",
      "GS": "Georgia del Sud e isole Sandwich meridionali",
      "GT": "Guatemala",
      "GU": "Guam",
      "GW": "Guinea-Bissau",
      "GY": "Guyana",
      "HK": "Hong Kong",
      "HM": "Isole Heard e McDonald",
      "HN": "Honduras",
      "HR": "Croazia",
      "HT": "Haiti",
      "HU": "Ungheria",
      "ID": "Indonesia",
      "IE": "Irlanda",
      "IL": "Israele",
      "IM": "Isola di Man",
      "IN": "India",
      "IO": "Territori Britannici dell'Oceano Indiano",
      "IQ": "Iraq",
      "IR": "Iran",
      "IS": "Islanda",
      "IT": "Italia",
      "JE": "Jersey",
      "JM": "Giamaica",
      "JO": "Giordania",
      "JP": "Giappone",
      "KE": "Kenya",
      "KG": "Kirghizistan",
      "KH": "Cambogia",
      "KI": "Kiribati",
      "KM": "Comore",
      "KN": "Saint Kitts e Nevis",
      "KP": "Corea del Nord",
      "KR": "Corea del Sud",
      "KV": "Kosovo",
      "KW": "Kuwait",
      "KY": "Isole Cayman",
      "KZ": "Kazakistan",
      "LA": "Laos",
      "LB": "Libano",
      "LC": "Santa Lucia",
      "LI": "Liechtenstein",
      "LK": "Sri Lanka",
      "LR": "Liberia",
      "LS": "Lesotho",
      "LT": "Lituania",
      "LU": "Lussemburgo",
      "LV": "Lettonia",
      "LY": "Libia",
      "MA": "Marocco",
      "MC": "Monaco",
      "MD": "Moldavia",
      "ME": "Montenegro",
      "MF": "Saint-Martin",
      "MG": "Madagascar",
      "MH": "Isole Marshall",
      "MK": "Macedonia",
      "ML": "Mali",
      "MM": "Birmania  Myanmar",
      "MN": "Mongolia",
      "MO": "Macao",
      "MP": "Isole Marianne Settentrionali",
      "MQ": "Martinica",
      "MR": "Mauritania",
      "MS": "Montserrat",
      "MT": "Malta",
      "MU": "Mauritius",
      "MV": "Maldive",
      "MW": "Malawi",
      "MX": "Messico",
      "MY": "Malesia",
      "MZ": "Mozambico",
      "NA": "Namibia",
      "NC": "Nuova Caledonia",
      "NE": "Niger",
      "NF": "Isola Norfolk",
      "NG": "Nigeria",
      "NI": "Nicaragua",
      "NL": "Paesi Bassi",
      "NO": "Norvegia",
      "NP": "Nepal",
      "NR": "Nauru",
      "NU": "Niue",
      "NZ": "Nuova Zelanda",
      "OM": "Oman",
      "PA": "Panamá",
      "PE": "Perù",
      "PF": "Polinesia Francese",
      "PG": "Papua Nuova Guinea",
      "PH": "Filippine",
      "PK": "Pakistan",
      "PL": "Polonia",
      "PM": "Saint Pierre e Miquelon",
      "PN": "Isole Pitcairn",
      "PR": "Porto Rico",
      "PS": "Stato di Palestina",
      "PT": "Portogallo",
      "PW": "Palau",
      "PY": "Paraguay",
      "QA": "Qatar",
      "RE": "Réunion",
      "RO": "Romania",
      "RS": "Serbia",
      "RU": "Russia",
      "RW": "Ruanda",
      "SA": "Arabia Saudita",
      "SB": "Isole Salomone",
      "SC": "Seychelles",
      "SD": "Sudan",
      "SE": "Svezia",
      "SG": "Singapore",
      "SH": "Sant'Elena, Isola di Ascensione e Tristan da Cunha",
      "SI": "Slovenia",
      "SJ": "Svalbard e Jan Mayen",
      "SK": "Slovacchia",
      "SL": "Sierra Leone",
      "SM": "San Marino",
      "SN": "Senegal",
      "SO": "Somalia",
      "SR": "Suriname",
      "SS": "Sudan del Sud",
      "ST": "São Tomé e Príncipe",
      "SV": "El Salvador",
      "SX": "Sint Maarten",
      "SY": "Siria",
      "SZ": "Swaziland",
      "TC": "Isole Turks e Caicos",
      "TD": "Ciad",
      "TF": "Territori Francesi del Sud",
      "TG": "Togo",
      "TH": "Thailandia",
      "TJ": "Tagikistan",
      "TK": "Tokelau",
      "TL": "Timor Est",
      "TM": "Turkmenistan",
      "TN": "Tunisia",
      "TO": "Tonga",
      "TR": "Turchia",
      "TT": "Trinidad e Tobago",
      "TV": "Tuvalu",
      "TW": "Repubblica di Cina",
      "TZ": "Tanzania",
      "UA": "Ucraina",
      "UG": "Uganda",
      "UM": "Isole minori esterne degli Stati Uniti",
      "US": "Stati Uniti d'America",
      "UY": "Uruguay",
      "UZ": "Uzbekistan",
      "VA": "Città del Vaticano",
      "VC": "Saint Vincent e Grenadine",
      "VE": "Venezuela",
      "VG": "Isole Vergini Britanniche",
      "VI": "Isole Vergini Americane",
      "VN": "Vietnam",
      "VU": "Vanuatu",
      "WF": "Wallis e Futuna",
      "WS": "Samoa",
      "YE": "Yemen",
      "YT": "Mayotte",
      "ZA": "Sudafrica",
      "ZM": "Zambia",
      "ZW": "Zimbabwe"
    },
    "ko": {
      "GH": "\uac00\ub098",
      "GA": "\uac00\ubd09",
      "GY": "\uac00\uc774\uc544\ub098",
      "GM": "\uac10\ube44\uc544",
      "GG": "\uac74\uc9c0",
      "GP": "\uacfc\ub4e4\ub8e8\ud504",
      "GT": "\uacfc\ud14c\ub9d0\ub77c",
      "GU": "\uad0c",
      "GD": "\uadf8\ub808\ub098\ub2e4",
      "GR": "\uadf8\ub9ac\uc2a4",
      "GL": "\uadf8\ub9b0\ub780\ub4dc",
      "GN": "\uae30\ub2c8",
      "GW": "\uae30\ub2c8\ube44\uc0ac\uc6b0",
      "NA": "\ub098\ubbf8\ube44\uc544",
      "NR": "\ub098\uc6b0\ub8e8",
      "NG": "\ub098\uc774\uc9c0\ub9ac\uc544",
      "AQ": "\ub0a8\uadf9 \ub300\ub959",
      "SS": "\ub0a8\uc218\ub2e8",
      "ZA": "\ub0a8\uc544\ud504\ub9ac\uce74",
      "NL": "\ub124\ub35c\ub780\ub4dc",
      "BQ": "\ub124\ub35c\ub780\ub4dc\ub839 \uce74\ub9ac\ube0c",
      "NP": "\ub124\ud314",
      "NO": "\ub178\ub974\uc6e8\uc774",
      "NF": "\ub178\ud37d\uc12c",
      "NZ": "\ub274\uc9c8\ub79c\ub4dc",
      "NC": "\ub274\uce7c\ub808\ub3c4\ub2c8\uc544",
      "NU": "\ub2c8\uc6b0\uc5d0",
      "NE": "\ub2c8\uc81c\ub974",
      "NI": "\ub2c8\uce74\ub77c\uacfc",
      "TW": "\ub300\ub9cc",
      "KR": "\ub300\ud55c\ubbfc\uad6d",
      "DK": "\ub374\ub9c8\ud06c",
      "DM": "\ub3c4\ubbf8\ub2c8\uce74",
      "DO": "\ub3c4\ubbf8\ub2c8\uce74 \uacf5\ud654\uad6d",
      "DE": "\ub3c5\uc77c",
      "TL": "\ub3d9\ud2f0\ubaa8\ub974",
      "LA": "\ub77c\uc624\uc2a4",
      "LR": "\ub77c\uc774\ubca0\ub9ac\uc544",
      "LV": "\ub77c\ud2b8\ube44\uc544",
      "RU": "\ub7ec\uc2dc\uc544",
      "LB": "\ub808\ubc14\ub17c",
      "LS": "\ub808\uc18c\ud1a0",
      "RO": "\ub8e8\ub9c8\ub2c8\uc544",
      "LU": "\ub8e9\uc148\ubd80\ub974\ud06c",
      "RW": "\ub974\uc644\ub2e4",
      "LY": "\ub9ac\ube44\uc544",
      "RE": "\ub9ac\uc720\ub2c8\uc628",
      "LT": "\ub9ac\ud22c\uc544\ub2c8\uc544",
      "LI": "\ub9ac\ud788\ud150\uc288\ud0c0\uc778",
      "MG": "\ub9c8\ub2e4\uac00\uc2a4\uce74\ub974",
      "MQ": "\ub9c8\ub974\ud2f0\ub2c8\ud06c",
      "MH": "\ub9c8\uc15c \uc81c\ub3c4",
      "YT": "\ub9c8\uc694\ud2b8",
      "MO": "\ub9c8\uce74\uc624(\uc911\uad6d \ud2b9\ubcc4\ud589\uc815\uad6c)",
      "MW": "\ub9d0\ub77c\uc704",
      "MY": "\ub9d0\ub808\uc774\uc2dc\uc544",
      "ML": "\ub9d0\ub9ac",
      "IM": "\ub9e8 \uc12c",
      "MX": "\uba55\uc2dc\ucf54",
      "MC": "\ubaa8\ub098\ucf54",
      "MA": "\ubaa8\ub85c\ucf54",
      "MU": "\ubaa8\ub9ac\uc154\uc2a4",
      "MR": "\ubaa8\ub9ac\ud0c0\ub2c8",
      "MZ": "\ubaa8\uc7a0\ube44\ud06c",
      "ME": "\ubaac\ud14c\ub124\uadf8\ub85c",
      "MS": "\ubaac\ud2b8\uc138\ub77c\ud2b8",
      "MD": "\ubab0\ub3c4\ubc14",
      "MV": "\ubab0\ub514\ube0c",
      "MT": "\ubab0\ud0c0",
      "MN": "\ubabd\uace8",
      "US": "\ubbf8\uad6d",
      "VI": "\ubbf8\uad6d\ub839 \ubc84\uc9c4\uc544\uc77c\ub79c\ub4dc",
      "UM": "\ubbf8\uad6d\ub839 \ud574\uc678 \uc81c\ub3c4",
      "MM": "\ubbf8\uc580\ub9c8",
      "FM": "\ubbf8\ud06c\ub85c\ub124\uc2dc\uc544",
      "VU": "\ubc14\ub204\uc544\ud22c",
      "BH": "\ubc14\ub808\uc778",
      "BB": "\ubc14\ubca0\uc774\ub3c4\uc2a4",
      "VA": "\ubc14\ud2f0\uce78 \uc2dc\uad6d",
      "BS": "\ubc14\ud558\ub9c8",
      "BD": "\ubc29\uae00\ub77c\ub370\uc2dc",
      "BM": "\ubc84\ubba4\ub2e4",
      "BJ": "\ubca0\ub0c9",
      "VE": "\ubca0\ub124\uc218\uc5d8\ub77c",
      "VN": "\ubca0\ud2b8\ub0a8",
      "BE": "\ubca8\uae30\uc5d0",
      "BY": "\ubca8\ub77c\ub8e8\uc2a4",
      "BZ": "\ubca8\ub9ac\uc988",
      "BA": "\ubcf4\uc2a4\ub2c8\uc544 \ud5e4\ub974\uccb4\uace0\ube44\ub098",
      "BW": "\ubcf4\uce20\uc640\ub098",
      "BO": "\ubcfc\ub9ac\ube44\uc544",
      "BI": "\ubd80\ub8ec\ub514",
      "BF": "\ubd80\ub974\ud0a4\ub098\ud30c\uc18c",
      "BV": "\ubd80\ubca0\uc12c",
      "BT": "\ubd80\ud0c4",
      "MP": "\ubd81\ub9c8\ub9ac\uc544\ub098\uc81c\ub3c4",
      "MK": "\ubd81\ub9c8\ucf00\ub3c4\ub2c8\uc544",
      "KP": "\ubd81\ud55c",
      "BG": "\ubd88\uac00\ub9ac\uc544",
      "BR": "\ube0c\ub77c\uc9c8",
      "BN": "\ube0c\ub8e8\ub098\uc774",
      "WS": "\uc0ac\ubaa8\uc544",
      "SA": "\uc0ac\uc6b0\ub514\uc544\ub77c\ube44\uc544",
      "GS": "\uc0ac\uc6b0\uc2a4\uc870\uc9c0\uc544 \uc0ac\uc6b0\uc2a4\uc0cc\ub4dc\uc704\uce58 \uc81c\ub3c4",
      "SM": "\uc0b0\ub9c8\ub9ac\ub178",
      "ST": "\uc0c1\ud22c\uba54 \ud504\ub9b0\uc2dc\ud398",
      "MF": "\uc0dd\ub9c8\ub974\ud0f1",
      "BL": "\uc0dd\ubc14\ub974\ud154\ub808\ubbf8",
      "PM": "\uc0dd\ud53c\uc5d0\ub974 \ubbf8\ud074\ub871",
      "EH": "\uc11c\uc0ac\ud558\ub77c",
      "SN": "\uc138\ub124\uac08",
      "RS": "\uc138\ub974\ube44\uc544",
      "SC": "\uc138\uc774\uc178",
      "LC": "\uc138\uc778\ud2b8\ub8e8\uc2dc\uc544",
      "VC": "\uc138\uc778\ud2b8\ube48\uc13c\ud2b8\uadf8\ub808\ub098\ub518",
      "KN": "\uc138\uc778\ud2b8\ud0a4\uce20 \ub124\ube44\uc2a4",
      "SH": "\uc138\uc778\ud2b8\ud5ec\ub808\ub098",
      "SO": "\uc18c\ub9d0\ub9ac\uc544",
      "SB": "\uc194\ub85c\ubaac \uc81c\ub3c4",
      "SD": "\uc218\ub2e8",
      "SR": "\uc218\ub9ac\ub0a8",
      "LK": "\uc2a4\ub9ac\ub791\uce74",
      "SJ": "\uc2a4\ubc1c\ubc14\ub974\uc81c\ub3c4-\uc580\ub9c8\uc6ec\uc12c",
      "SE": "\uc2a4\uc6e8\ub374",
      "CH": "\uc2a4\uc704\uc2a4",
      "ES": "\uc2a4\ud398\uc778",
      "SK": "\uc2ac\ub85c\ubc14\ud0a4\uc544",
      "SI": "\uc2ac\ub85c\ubca0\ub2c8\uc544",
      "SY": "\uc2dc\ub9ac\uc544",
      "SL": "\uc2dc\uc5d0\ub77c\ub9ac\uc628",
      "SX": "\uc2e0\ud2b8\ub9c8\ub974\ud134",
      "SG": "\uc2f1\uac00\ud3ec\ub974",
      "AE": "\uc544\ub78d\uc5d0\ubbf8\ub9ac\ud2b8",
      "AW": "\uc544\ub8e8\ubc14",
      "AM": "\uc544\ub974\uba54\ub2c8\uc544",
      "AR": "\uc544\ub974\ud5e8\ud2f0\ub098",
      "AS": "\uc544\uba54\ub9ac\uce78 \uc0ac\ubaa8\uc544",
      "IS": "\uc544\uc774\uc2ac\ub780\ub4dc",
      "HT": "\uc544\uc774\ud2f0",
      "IE": "\uc544\uc77c\ub79c\ub4dc",
      "AZ": "\uc544\uc81c\ub974\ubc14\uc774\uc794",
      "AF": "\uc544\ud504\uac00\ub2c8\uc2a4\ud0c4",
      "AD": "\uc548\ub3c4\ub77c",
      "AL": "\uc54c\ubc14\ub2c8\uc544",
      "DZ": "\uc54c\uc81c\ub9ac",
      "AO": "\uc559\uace8\ub77c",
      "AG": "\uc564\ud2f0\uac00 \ubc14\ubd80\ub2e4",
      "AI": "\uc575\uadc8\ub77c",
      "ER": "\uc5d0\ub9ac\ud2b8\ub9ac\uc544",
      "SZ": "\uc5d0\uc2a4\uc640\ud2f0\ub2c8",
      "EE": "\uc5d0\uc2a4\ud1a0\ub2c8\uc544",
      "EC": "\uc5d0\ucf70\ub3c4\ub974",
      "ET": "\uc5d0\ud2f0\uc624\ud53c\uc544",
      "SV": "\uc5d8\uc0b4\ubc14\ub3c4\ub974",
      "GB": "\uc601\uad6d",
      "VG": "\uc601\uad6d\ub839 \ubc84\uc9c4\uc544\uc77c\ub79c\ub4dc",
      "IO": "\uc601\uad6d\ub839 \uc778\ub3c4\uc591 \uc2dd\ubbfc\uc9c0",
      "YE": "\uc608\uba58",
      "OM": "\uc624\ub9cc",
      "AU": "\uc624\uc2a4\ud2b8\ub808\uc77c\ub9ac\uc544",
      "AT": "\uc624\uc2a4\ud2b8\ub9ac\uc544",
      "HN": "\uc628\ub450\ub77c\uc2a4",
      "AX": "\uc62c\ub780\ub4dc \uc81c\ub3c4",
      "WF": "\uc648\ub9ac\uc2a4-\ud478\ud22c\ub098 \uc81c\ub3c4",
      "JO": "\uc694\ub974\ub2e8",
      "UG": "\uc6b0\uac04\ub2e4",
      "UY": "\uc6b0\ub8e8\uacfc\uc774",
      "UZ": "\uc6b0\uc988\ubca0\ud0a4\uc2a4\ud0c4",
      "UA": "\uc6b0\ud06c\ub77c\uc774\ub098",
      "IQ": "\uc774\ub77c\ud06c",
      "IR": "\uc774\ub780",
      "IL": "\uc774\uc2a4\ub77c\uc5d8",
      "EG": "\uc774\uc9d1\ud2b8",
      "IT": "\uc774\ud0c8\ub9ac\uc544",
      "IN": "\uc778\ub3c4",
      "ID": "\uc778\ub3c4\ub124\uc2dc\uc544",
      "JP": "\uc77c\ubcf8",
      "JM": "\uc790\uba54\uc774\uce74",
      "ZM": "\uc7a0\ube44\uc544",
      "JE": "\uc800\uc9c0",
      "GQ": "\uc801\ub3c4 \uae30\ub2c8",
      "GE": "\uc870\uc9c0\uc544",
      "CN": "\uc911\uad6d",
      "CF": "\uc911\uc559 \uc544\ud504\ub9ac\uce74 \uacf5\ud654\uad6d",
      "DJ": "\uc9c0\ubd80\ud2f0",
      "GI": "\uc9c0\ube0c\ub864\ud130",
      "ZW": "\uc9d0\ubc14\ube0c\uc6e8",
      "TD": "\ucc28\ub4dc",
      "CZ": "\uccb4\ucf54",
      "CL": "\uce60\ub808",
      "CM": "\uce74\uba54\ub8ec",
      "CV": "\uce74\ubcf4\ubca0\ub974\ub370",
      "KZ": "\uce74\uc790\ud750\uc2a4\ud0c4",
      "QA": "\uce74\ud0c0\ub974",
      "KH": "\uce84\ubcf4\ub514\uc544",
      "CA": "\uce90\ub098\ub2e4",
      "KE": "\ucf00\ub0d0",
      "KY": "\ucf00\uc774\ub9e8 \uc81c\ub3c4",
      "KV": "코소보",
      "KM": "\ucf54\ubaa8\ub85c",
      "CR": "\ucf54\uc2a4\ud0c0\ub9ac\uce74",
      "CC": "\ucf54\ucf54\uc2a4 \uc81c\ub3c4",
      "CI": "\ucf54\ud2b8\ub514\ubd80\uc544\ub974",
      "CO": "\ucf5c\ub86c\ube44\uc544",
      "CG": "\ucf69\uace0-\ube0c\ub77c\uc790\ube4c",
      "CD": "\ucf69\uace0-\ud0a8\uc0e4\uc0ac",
      "CU": "\ucfe0\ubc14",
      "KW": "\ucfe0\uc6e8\uc774\ud2b8",
      "CK": "\ucfe1 \uc81c\ub3c4",
      "CW": "\ud034\ub77c\uc18c",
      "HR": "\ud06c\ub85c\uc544\ud2f0\uc544",
      "CX": "\ud06c\ub9ac\uc2a4\ub9c8\uc2a4\uc12c",
      "KG": "\ud0a4\ub974\uae30\uc2a4\uc2a4\ud0c4",
      "KI": "\ud0a4\ub9ac\ubc14\uc2dc",
      "CY": "\ud0a4\ud504\ub85c\uc2a4",
      "TJ": "\ud0c0\uc9c0\ud0a4\uc2a4\ud0c4",
      "TZ": "\ud0c4\uc790\ub2c8\uc544",
      "TH": "\ud0dc\uad6d",
      "TC": "\ud130\ud06c\uc2a4 \ucf00\uc774\ucee4\uc2a4 \uc81c\ub3c4",
      "TR": "\ud130\ud0a4",
      "TG": "\ud1a0\uace0",
      "TK": "\ud1a0\ucf08\ub77c\uc6b0",
      "TO": "\ud1b5\uac00",
      "TM": "\ud22c\ub974\ud06c\uba54\ub2c8\uc2a4\ud0c4",
      "TV": "\ud22c\ubc1c\ub8e8",
      "TN": "\ud280\ub2c8\uc9c0",
      "TT": "\ud2b8\ub9ac\ub2c8\ub2e4\ub4dc \ud1a0\ubc14\uace0",
      "PA": "\ud30c\ub098\ub9c8",
      "PY": "\ud30c\ub77c\uacfc\uc774",
      "PK": "\ud30c\ud0a4\uc2a4\ud0c4",
      "PG": "\ud30c\ud478\uc544\ub274\uae30\ub2c8",
      "PW": "\ud314\ub77c\uc6b0",
      "PS": "\ud314\ub808\uc2a4\ud0c0\uc778 \uc9c0\uad6c",
      "FO": "\ud398\ub85c \uc81c\ub3c4",
      "PE": "\ud398\ub8e8",
      "PT": "\ud3ec\ub974\ud22c\uac08",
      "FK": "\ud3ec\ud074\ub79c\ub4dc \uc81c\ub3c4",
      "PL": "\ud3f4\ub780\ub4dc",
      "PR": "\ud478\uc5d0\ub974\ud1a0\ub9ac\ucf54",
      "FR": "\ud504\ub791\uc2a4",
      "TF": "\ud504\ub791\uc2a4 \ub0a8\ubd80 \uc9c0\ubc29",
      "GF": "\ud504\ub791\uc2a4\ub839 \uae30\uc544\ub098",
      "PF": "\ud504\ub791\uc2a4\ub839 \ud3f4\ub9ac\ub124\uc2dc\uc544",
      "FJ": "\ud53c\uc9c0",
      "FI": "\ud540\ub780\ub4dc",
      "PH": "\ud544\ub9ac\ud540",
      "PN": "\ud54f\ucf00\uc5b8 \uc12c",
      "HM": "\ud5c8\ub4dc \ub9e5\ub3c4\ub110\ub4dc \uc81c\ub3c4",
      "HU": "\ud5dd\uac00\ub9ac",
      "HK": "\ud64d\ucf69(\uc911\uad6d \ud2b9\ubcc4\ud589\uc815\uad6c)"
    },
    "pt": {
      "AF": "Afeganistão",
      "ZA": "África do Sul",
      "AL": "Albânia",
      "DE": "Alemanha",
      "AD": "Andorra",
      "AO": "Angola",
      "AI": "Anguilla",
      "AQ": "Antártida",
      "AG": "Antígua e Barbuda",
      "SA": "Arábia Saudita",
      "DZ": "Argélia",
      "AR": "Argentina",
      "AM": "Armênia",
      "AW": "Aruba",
      "AU": "Austrália",
      "AT": "Áustria",
      "AZ": "Azerbaijão",
      "BS": "Bahamas",
      "BH": "Bahrein",
      "BD": "Bangladesh",
      "BB": "Barbados",
      "BE": "Bélgica",
      "BZ": "Belize",
      "BJ": "Benin",
      "BM": "Bermudas",
      "BY": "Bielorrússia",
      "BO": "Bolívia",
      "BA": "Bósnia e Herzegovina",
      "BW": "Botsuana",
      "BR": "Brasil",
      "BN": "Brunei",
      "BG": "Bulgária",
      "BF": "Burquina Faso",
      "BI": "Burundi",
      "BT": "Butão",
      "CV": "Cabo Verde",
      "KH": "Camboja",
      "CA": "Canadá",
      "QA": "Catar",
      "KZ": "Cazaquistão",
      "TD": "Chade",
      "CL": "Chile",
      "CN": "China",
      "CY": "Chipre",
      "VA": "Cidade do Vaticano",
      "SG": "Cingapura",
      "CO": "Colômbia",
      "KM": "Comores",
      "CG": "Congo - Brazzaville",
      "CD": "Congo - Kinshasa",
      "KP": "Coreia do Norte",
      "KR": "Coreia do Sul",
      "CI": "Costa do Marfim",
      "CR": "Costa Rica",
      "HR": "Croácia",
      "CU": "Cuba",
      "CW": "Curaçao",
      "DK": "Dinamarca",
      "DJ": "Djibuti",
      "DM": "Dominica",
      "EG": "Egito",
      "SV": "El Salvador",
      "AE": "Emirados Árabes Unidos",
      "EC": "Equador",
      "ER": "Eritreia",
      "SK": "Eslováquia",
      "SI": "Eslovênia",
      "ES": "Espanha",
      "US": "Estados Unidos",
      "EE": "Estônia",
      "ET": "Etiópia",
      "FJ": "Fiji",
      "PH": "Filipinas",
      "FI": "Finlândia",
      "FR": "França",
      "GA": "Gabão",
      "GM": "Gâmbia",
      "GH": "Gana",
      "GE": "Geórgia",
      "GS": "Geórgia do Sul e Ilhas Sandwich do Sul",
      "GI": "Gibraltar",
      "GD": "Granada",
      "GR": "Grécia",
      "GL": "Groenlândia",
      "GP": "Guadalupe",
      "GU": "Guam",
      "GT": "Guatemala",
      "GG": "Guernsey",
      "GY": "Guiana",
      "GF": "Guiana Francesa",
      "GN": "Guiné",
      "GW": "Guiné Bissau",
      "GQ": "Guiné Equatorial",
      "HT": "Haiti",
      "NL": "Holanda",
      "HN": "Honduras",
      "HK": "Hong Kong, RAE da China",
      "HU": "Hungria",
      "YE": "Iêmen",
      "BV": "Ilhas Bouvet",
      "CX": "Ilha Christmas",
      "IM": "Ilha de Man",
      "NF": "Ilha Norfolk",
      "AX": "Ilhas Åland",
      "KY": "Ilhas Caiman",
      "CC": "Ilhas Cocos (Keeling)",
      "CK": "Ilhas Cook",
      "UM": "Ilhas Distantes dos EUA",
      "HM": "Ilha Heard e Ilha McDonald",
      "FO": "Ilhas Faroe",
      "FK": "Ilhas Malvinas",
      "MP": "Ilhas Marianas do Norte",
      "MH": "Ilhas Marshall",
      "PN": "Ilhas Pitcairn",
      "KV": "Kosovo",
      "SB": "Ilhas Salomão",
      "TC": "Ilhas Turks e Caicos",
      "VG": "Ilhas Virgens Britânicas",
      "VI": "Ilhas Virgens dos EUA",
      "IN": "Índia",
      "ID": "Indonésia",
      "IR": "Irã",
      "IQ": "Iraque",
      "IE": "Irlanda",
      "IS": "Islândia",
      "IL": "Israel",
      "IT": "Itália",
      "JM": "Jamaica",
      "JP": "Japão",
      "JE": "Jersey",
      "JO": "Jordânia",
      "KW": "Kuwait",
      "LA": "Laos",
      "LS": "Lesoto",
      "LV": "Letônia",
      "LB": "Líbano",
      "LR": "Libéria",
      "LY": "Líbia",
      "LI": "Liechtenstein",
      "LT": "Lituânia",
      "LU": "Luxemburgo",
      "MO": "Macau, RAE da China",
      "MK": "Macedônia",
      "MG": "Madagascar",
      "MY": "Malásia",
      "MW": "Malawi",
      "MV": "Maldivas",
      "ML": "Mali",
      "MT": "Malta",
      "MA": "Marrocos",
      "MQ": "Martinica",
      "MU": "Maurício",
      "MR": "Mauritânia",
      "YT": "Mayotte",
      "MX": "México",
      "MM": "Mianmar (Birmânia)",
      "FM": "Micronésia",
      "MZ": "Moçambique",
      "MD": "Moldávia",
      "MC": "Mônaco",
      "MN": "Mongólia",
      "ME": "Montenegro",
      "MS": "Montserrat",
      "NA": "Namíbia",
      "NR": "Nauru",
      "NP": "Nepal",
      "NI": "Nicarágua",
      "NE": "Níger",
      "NG": "Nigéria",
      "NU": "Niue",
      "NO": "Noruega",
      "NC": "Nova Caledônia",
      "NZ": "Nova Zelândia",
      "OM": "Omã",
      "BQ": "Países Baixos Caribenhos",
      "PW": "Palau",
      "PA": "Panamá",
      "PG": "Papua-Nova Guiné",
      "PK": "Paquistão",
      "PY": "Paraguai",
      "PE": "Peru",
      "PF": "Polinésia Francesa",
      "PL": "Polônia",
      "PR": "Porto Rico",
      "PT": "Portugal",
      "KE": "Quênia",
      "KG": "Quirguistão",
      "KI": "Quiribati",
      "GB": "Reino Unido",
      "CF": "República Centro-Africana",
      "DO": "República Dominicana",
      "CM": "República dos Camarões",
      "CZ": "República Tcheca",
      "RE": "Reunião",
      "RO": "Romênia",
      "RW": "Ruanda",
      "RU": "Rússia",
      "EH": "Saara Ocidental",
      "PM": "Saint Pierre e Miquelon",
      "WS": "Samoa",
      "AS": "Samoa Americana",
      "SM": "San Marino",
      "SH": "Santa Helena",
      "LC": "Santa Lúcia",
      "BL": "São Bartolomeu",
      "KN": "São Cristóvão e Nevis",
      "MF": "São Martinho",
      "ST": "São Tomé e Príncipe",
      "VC": "São Vicente e Granadinas",
      "SN": "Senegal",
      "SL": "Serra Leoa",
      "RS": "Sérvia",
      "SC": "Seychelles",
      "SX": "Sint Maarten",
      "SY": "Síria",
      "SO": "Somália",
      "LK": "Sri Lanka",
      "SZ": "Suazilândia",
      "SD": "Sudão",
      "SS": "Sudão do Sul",
      "SE": "Suécia",
      "CH": "Suíça",
      "SR": "Suriname",
      "SJ": "Svalbard e Jan Mayen",
      "TH": "Tailândia",
      "TW": "Taiwan",
      "TJ": "Tajiquistão",
      "TZ": "Tanzânia",
      "IO": "Território Britânico do Oceano Índico",
      "TF": "Territórios Franceses do Sul",
      "PS": "Territórios palestinos",
      "TL": "Timor-Leste",
      "TG": "Togo",
      "TK": "Tokelau",
      "TO": "Tonga",
      "TT": "Trinidad e Tobago",
      "TN": "Tunísia",
      "TM": "Turcomenistão",
      "TR": "Turquia",
      "TV": "Tuvalu",
      "UA": "Ucrânia",
      "UG": "Uganda",
      "UY": "Uruguai",
      "UZ": "Uzbequistão",
      "VU": "Vanuatu",
      "VE": "Venezuela",
      "VN": "Vietnã",
      "WF": "Wallis e Futuna",
      "ZM": "Zâmbia",
      "ZW": "Zimbábue"
    },
    "ru": {
      "AU": "Австралия",
      "AT": "Австрия",
      "AZ": "Азербайджан",
      "AX": "Аландские острова",
      "AL": "Албания",
      "DZ": "Алжир",
      "VI": "Виргинские Острова (США)",
      "AS": "Американское Самоа",
      "AI": "Ангилья",
      "AO": "Ангола",
      "AD": "Андорра",
      "AQ": "Антарктида",
      "AG": "Антигуа и Барбуда",
      "AR": "Аргентина",
      "AM": "Армения",
      "AW": "Аруба",
      "AF": "Афганистан",
      "BS": "Багамы",
      "BD": "Бангладеш",
      "BB": "Барбадос",
      "BH": "Бахрейн",
      "BZ": "Белиз",
      "BY": "Беларусь",
      "BE": "Бельгия",
      "BJ": "Бенин",
      "BM": "Бермуды",
      "BG": "Болгария",
      "BO": "Боливия",
      "BQ": "Бонэйр, Синт-Эстатиус и Саба",
      "BA": "Босния и Герцеговина",
      "BW": "Ботсвана",
      "BR": "Бразилия",
      "IO": "Британская территория в Индийском океане",
      "VG": "Виргинские Острова (Великобритания)",
      "BN": "Бруней",
      "BF": "Буркина-Фасо",
      "BI": "Бурунди",
      "BT": "Бутан",
      "VU": "Вануату",
      "VA": "Ватикан",
      "GB": "Великобритания",
      "HU": "Венгрия",
      "VE": "Венесуэла",
      "UM": "Внешние малые острова (США)",
      "TL": "Восточный Тимор",
      "VN": "Вьетнам",
      "GA": "Габон",
      "HT": "Гаити",
      "GY": "Гайана",
      "GM": "Гамбия",
      "GH": "Гана",
      "GP": "Гваделупа",
      "GT": "Гватемала",
      "GF": "Гвиана",
      "GN": "Гвинея",
      "GW": "Гвинея-Бисау",
      "DE": "Германия",
      "GG": "Гернси",
      "GI": "Гибралтар",
      "HN": "Гондурас",
      "HK": "Гонконг",
      "GD": "Гренада",
      "GL": "Гренландия",
      "GR": "Греция",
      "GE": "Грузия",
      "GU": "Гуам",
      "DK": "Дания",
      "JE": "Джерси",
      "DJ": "Джибути",
      "DM": "Доминика",
      "DO": "Доминиканская Республика",
      "CD": "Демократическая Республика Конго",
      "EG": "Египет",
      "ZM": "Замбия",
      "EH": "САДР",
      "ZW": "Зимбабве",
      "IL": "Израиль",
      "IN": "Индия",
      "ID": "Индонезия",
      "JO": "Иордания",
      "IQ": "Ирак",
      "IR": "Иран",
      "IE": "Ирландия",
      "IS": "Исландия",
      "ES": "Испания",
      "IT": "Италия",
      "YE": "Йемен",
      "CV": "Кабо-Верде",
      "KZ": "Казахстан",
      "KY": "Острова Кайман",
      "KH": "Камбоджа",
      "CM": "Камерун",
      "CA": "Канада",
      "QA": "Катар",
      "KE": "Кения",
      "CY": "Кипр",
      "KG": "Киргизия",
      "KI": "Кирибати",
      "TW": "Китайская Республика",
      "KP": "КНДР (Корейская Народно-Демократическая Республика)",
      "CN": "КНР (Китайская Народная Республика)",
      "CC": "Кокосовые острова",
      "CO": "Колумбия",
      "KM": "Коморы",
      "CR": "Коста-Рика",
      "CI": "Кот-д’Ивуар",
      "CU": "Куба",
      "KW": "Кувейт",
      "CW": "Кюрасао",
      "LA": "Лаос",
      "LV": "Латвия",
      "LS": "Лесото",
      "LR": "Либерия",
      "LB": "Ливан",
      "LY": "Ливия",
      "LT": "Литва",
      "LI": "Лихтенштейн",
      "LU": "Люксембург",
      "MU": "Маврикий",
      "MR": "Мавритания",
      "MG": "Мадагаскар",
      "YT": "Майотта",
      "MO": "Макао",
      "MK": "Македония",
      "MW": "Малави",
      "MY": "Малайзия",
      "ML": "Мали",
      "MV": "Мальдивы",
      "MT": "Мальта",
      "MA": "Марокко",
      "MQ": "Мартиника",
      "MH": "Маршалловы Острова",
      "MX": "Мексика",
      "FM": "Микронезия",
      "MZ": "Мозамбик",
      "MD": "Молдавия",
      "MC": "Монако",
      "MN": "Монголия",
      "MS": "Монтсеррат",
      "MM": "Мьянма",
      "NA": "Намибия",
      "NR": "Науру",
      "NP": "Непал",
      "NE": "Нигер",
      "NG": "Нигерия",
      "NL": "Нидерланды",
      "NI": "Никарагуа",
      "NU": "Ниуэ",
      "NZ": "Новая Зеландия",
      "NC": "Новая Каледония",
      "NO": "Норвегия",
      "AE": "ОАЭ",
      "OM": "Оман",
      "BV": "Остров Буве",
      "IM": "Остров Мэн",
      "CK": "Острова Кука",
      "NF": "Остров Норфолк",
      "CX": "Остров Рождества",
      "PN": "Острова Питкэрн",
      "SH": "Острова Святой Елены, Вознесения и Тристан-да-Кунья",
      "PK": "Пакистан",
      "PW": "Палау",
      "PS": "Государство Палестина",
      "PA": "Панама",
      "PG": "Папуа — Новая Гвинея",
      "PY": "Парагвай",
      "PE": "Перу",
      "PL": "Польша",
      "PT": "Португалия",
      "PR": "Пуэрто-Рико",
      "CG": "Республика Конго",
      "KR": "Республика Корея",
      "RE": "Реюньон",
      "RU": "Россия",
      "RW": "Руанда",
      "RO": "Румыния",
      "SV": "Сальвадор",
      "WS": "Самоа",
      "SM": "Сан-Марино",
      "ST": "Сан-Томе и Принсипи",
      "SA": "Саудовская Аравия",
      "SZ": "Свазиленд",
      "MP": "Северные Марианские Острова",
      "SC": "Сейшельские Острова",
      "BL": "Сен-Бартелеми",
      "MF": "Сен-Мартен",
      "PM": "Сен-Пьер и Микелон",
      "SN": "Сенегал",
      "VC": "Сент-Винсент и Гренадины",
      "KN": "Сент-Китс и Невис",
      "LC": "Сент-Люсия",
      "RS": "Сербия",
      "SG": "Сингапур",
      "SX": "Синт-Мартен",
      "SY": "Сирия",
      "SK": "Словакия",
      "SI": "Словения",
      "SB": "Соломоновы Острова",
      "SO": "Сомали",
      "SD": "Судан",
      "SR": "Суринам",
      "US": "США",
      "SL": "Сьерра-Леоне",
      "TJ": "Таджикистан",
      "TH": "Таиланд",
      "TZ": "Танзания",
      "TC": "Теркс и Кайкос",
      "TG": "Того",
      "TK": "Токелау",
      "TO": "Тонга",
      "TT": "Тринидад и Тобаго",
      "TV": "Тувалу",
      "TN": "Тунис",
      "TM": "Туркмения",
      "TR": "Турция",
      "UG": "Уганда",
      "UZ": "Узбекистан",
      "UA": "Украина",
      "WF": "Уоллис и Футуна",
      "UY": "Уругвай",
      "FO": "Фареры",
      "FJ": "Фиджи",
      "PH": "Филиппины",
      "FI": "Финляндия",
      "FK": "Фолклендские острова",
      "FR": "Франция",
      "PF": "Французская Полинезия",
      "TF": "Французские Южные и Антарктические Территории",
      "HM": "Херд и Макдональд",
      "HR": "Хорватия",
      "CF": "ЦАР",
      "TD": "Чад",
      "KV": "Косово",
      "ME": "Черногория",
      "CZ": "Чехия",
      "CL": "Чили",
      "CH": "Швейцария",
      "SE": "Швеция",
      "SJ": "Шпицберген и Ян-Майен",
      "LK": "Шри-Ланка",
      "EC": "Эквадор",
      "GQ": "Экваториальная Гвинея",
      "ER": "Эритрея",
      "EE": "Эстония",
      "ET": "Эфиопия",
      "ZA": "ЮАР",
      "GS": "Южная Георгия и Южные Сандвичевы Острова",
      "SS": "Южный Судан",
      "JM": "Ямайка",
      "JP": "Япония"
    },
    "zh": {
      "AD": "安道尔",
      "AE": "阿联酋",
      "AF": "阿富汗",
      "AG": "安地卡及巴布达",
      "AI": "安圭拉",
      "AL": "阿尔巴尼亚",
      "AM": "亚美尼亚",
      "AO": "安哥拉",
      "AQ": "南极洲",
      "AR": "阿根廷",
      "AS": "美属萨摩亚",
      "AT": "奥地利",
      "AU": "澳大利亚",
      "AW": "阿鲁巴",
      "AX": "奥兰",
      "AZ": "阿塞拜疆",
      "BA": "波斯尼亚和黑塞哥维那",
      "BB": "巴巴多斯",
      "BD": "孟加拉国",
      "BE": "比利时",
      "BF": "布吉纳法索",
      "BG": "保加利亚",
      "BH": "巴林",
      "BI": "布隆迪",
      "BJ": "贝宁",
      "BL": "圣巴泰勒米",
      "BM": "百慕大",
      "BN": "文莱",
      "BO": "玻利维亚",
      "BQ": "加勒比荷兰",
      "BR": "巴西",
      "BS": "巴哈马",
      "BT": "不丹",
      "BV": "布韦岛",
      "BW": "博茨瓦纳",
      "BY": "白俄罗斯",
      "BZ": "伯利兹",
      "CA": "加拿大",
      "CC": "科科斯（基林）群岛",
      "CD": "刚果（金)",
      "CF": "中非",
      "CG": "刚果（布)",
      "CH": "瑞士",
      "CI": "科特迪瓦",
      "CK": "库克群岛",
      "CL": "智利",
      "CM": "喀麦隆",
      "CN": "中国",
      "CO": "哥伦比亚",
      "CR": "哥斯达黎加",
      "CU": "古巴",
      "CV": "佛得角",
      "CW": "库拉索",
      "CX": "圣诞岛",
      "CY": "赛普勒斯",
      "CZ": "捷克",
      "DE": "德国",
      "DJ": "吉布提",
      "DK": "丹麦",
      "DM": "多米尼克",
      "DO": "多米尼加",
      "DZ": "阿尔及利亚",
      "EC": "厄瓜多尔",
      "EE": "爱沙尼亚",
      "EG": "埃及",
      "EH": "阿拉伯撒哈拉民主共和国",
      "ER": "厄立特里亚",
      "ES": "西班牙",
      "ET": "衣索比亚",
      "FI": "芬兰",
      "FJ": "斐济",
      "FK": "福克兰群岛",
      "FM": "密克罗尼西亚联邦",
      "FO": "法罗群岛",
      "FR": "法国",
      "GA": "加彭",
      "GB": "英国",
      "GD": "格瑞那达",
      "GE": "格鲁吉亚",
      "GF": "法属圭亚那",
      "GG": "根西",
      "GH": "加纳",
      "GI": "直布罗陀",
      "GL": "格陵兰",
      "GM": "冈比亚",
      "GN": "几内亚",
      "GP": "瓜德罗普",
      "GQ": "赤道几内亚",
      "GR": "希腊",
      "GS": "南乔治亚和南桑威奇群岛",
      "GT": "危地马拉",
      "GU": "关岛",
      "GW": "几内亚比绍",
      "GY": "圭亚那",
      "HK": "香港",
      "HM": "赫德岛和麦克唐纳群岛",
      "HN": "宏都拉斯",
      "HR": "克罗地亚",
      "HT": "海地",
      "HU": "匈牙利",
      "ID": "印尼",
      "IE": "爱尔兰",
      "IL": "以色列",
      "IM": "马恩岛",
      "IN": "印度",
      "IO": "英属印度洋领地",
      "IQ": "伊拉克",
      "IR": "伊朗",
      "IS": "冰岛",
      "IT": "意大利",
      "JE": "泽西",
      "JM": "牙买加",
      "JO": "约旦",
      "JP": "日本",
      "KE": "肯尼亚",
      "KG": "吉尔吉斯斯坦",
      "KH": "柬埔寨",
      "KI": "基里巴斯",
      "KM": "科摩罗",
      "KN": "圣基茨和尼维斯",
      "KP": "朝鲜",
      "KR": "韩国",
      "KV": "科索沃",
      "KW": "科威特",
      "KY": "开曼群岛",
      "KZ": "哈萨克斯坦",
      "LA": "老挝",
      "LB": "黎巴嫩",
      "LC": "圣卢西亚",
      "LI": "列支敦斯登",
      "LK": "斯里兰卡",
      "LR": "利比里亚",
      "LS": "赖索托",
      "LT": "立陶宛",
      "LU": "卢森堡",
      "LV": "拉脱维亚",
      "LY": "利比亚",
      "MA": "摩洛哥",
      "MC": "摩纳哥",
      "MD": "摩尔多瓦",
      "ME": "蒙特内哥罗",
      "MF": "法属圣马丁",
      "MG": "马达加斯加",
      "MH": "马绍尔群岛",
      "MK": "马其顿",
      "ML": "马里",
      "MM": "缅甸",
      "MN": "蒙古",
      "MO": "澳门",
      "MP": "北马里亚纳群岛",
      "MQ": "马提尼克",
      "MR": "毛里塔尼亚",
      "MS": "蒙特塞拉特",
      "MT": "马尔他",
      "MU": "模里西斯",
      "MV": "马尔地夫",
      "MW": "马拉维",
      "MX": "墨西哥",
      "MY": "马来西亚",
      "MZ": "莫桑比克",
      "NA": "纳米比亚",
      "NC": "新喀里多尼亚",
      "NE": "尼日尔",
      "NF": "诺福克岛",
      "NG": "奈及利亚",
      "NI": "尼加拉瓜",
      "NL": "荷兰",
      "NO": "挪威",
      "NP": "尼泊尔",
      "NR": "瑙鲁",
      "NU": "纽埃",
      "NZ": "新西兰",
      "OM": "阿曼",
      "PA": "巴拿马",
      "PE": "秘鲁",
      "PF": "法属玻里尼西亚",
      "PG": "巴布亚新几内亚",
      "PH": "菲律宾",
      "PK": "巴基斯坦",
      "PL": "波兰",
      "PM": "圣皮埃尔和密克隆",
      "PN": "皮特凯恩群岛",
      "PR": "波多黎各",
      "PS": "巴勒斯坦",
      "PT": "葡萄牙",
      "PW": "帛琉",
      "PY": "巴拉圭",
      "QA": "卡塔尔",
      "RE": "留尼汪",
      "RO": "罗马尼亚",
      "RS": "塞尔维亚",
      "RU": "俄罗斯",
      "RW": "卢旺达",
      "SA": "沙乌地阿拉伯",
      "SB": "所罗门群岛",
      "SC": "塞舌尔",
      "SD": "苏丹",
      "SE": "瑞典",
      "SG": "新加坡",
      "SH": "圣赫勒拿",
      "SI": "斯洛维尼亚",
      "SJ": "斯瓦尔巴群岛和扬马延岛",
      "SK": "斯洛伐克",
      "SL": "塞拉利昂",
      "SM": "圣马力诺",
      "SN": "塞内加尔",
      "SO": "索马利亚",
      "SR": "苏里南",
      "SS": "南苏丹",
      "ST": "圣多美和普林西比",
      "SV": "萨尔瓦多",
      "SX": "荷属圣马丁",
      "SY": "叙利亚",
      "SZ": "斯威士兰",
      "TC": "特克斯和凯科斯群岛",
      "TD": "乍得",
      "TF": "法属南部领地",
      "TG": "多哥",
      "TH": "泰国",
      "TJ": "塔吉克斯坦",
      "TK": "托克劳",
      "TL": "东帝汶",
      "TM": "土库曼斯坦",
      "TN": "突尼西亚",
      "TO": "汤加",
      "TR": "土耳其",
      "TT": "千里达及托巴哥",
      "TV": "图瓦卢",
      "TW": "臺湾",
      "TZ": "坦桑尼亚",
      "UA": "乌克兰",
      "UG": "乌干达",
      "UM": "美国本土外小岛屿",
      "US": "美国",
      "UY": "乌拉圭",
      "UZ": "乌兹别克斯坦",
      "VA": "梵蒂冈",
      "VC": "圣文森及格瑞那丁",
      "VE": "委内瑞拉",
      "VG": "英属维尔京群岛",
      "VI": "美属维尔京群岛",
      "VN": "越南",
      "VU": "瓦努阿图",
      "WF": "瓦利斯和富图纳",
      "WS": "萨摩亚",
      "YE": "叶门",
      "YT": "马约特",
      "ZA": "南非",
      "ZM": "尚比亚",
      "ZW": "辛巴威"
    }
  };

  final Map<String, String> _countryCurrency = {
    "AC": "USD",
    "AD": "EUR",
    "AE": "AED",
    "AF": "AFN",
    "AG": "XCD",
    "AI": "XCD",
    "AL": "ALL",
    "AM": "AMD",
    "AO": "AOA",
    "AR": "ARS",
    "AS": "USD",
    "AT": "EUR",
    "AU": "AUD",
    "AW": "AWG",
    "AX": "EUR",
    "AZ": "AZN",
    "BA": "BAM",
    "BB": "BBD",
    "BD": "BDT",
    "BE": "EUR",
    "BF": "XOF",
    "BG": "BGN",
    "BH": "BHD",
    "BI": "BIF",
    "BJ": "XOF",
    "BL": "EUR",
    "BM": "BMD",
    "BN": "BND",
    "BO": "BOB",
    "BQ": "USD",
    "BR": "BRL",
    "BS": "BSD",
    "BT": "INR",
    "BV": "NOK",
    "BW": "BWP",
    "BY": "BYN",
    "BZ": "BZD",
    "CA": "CAD",
    "CC": "AUD",
    "CD": "CDF",
    "CF": "XAF",
    "CG": "XAF",
    "CH": "CHF",
    "CI": "XOF",
    "CK": "NZD",
    "CL": "CLP",
    "CM": "XAF",
    "CN": "CNY",
    "CO": "COP",
    "CP": "EUR",
    "CR": "CRC",
    "CU": "CUP",
    "CV": "CVE",
    "CW": "ANG",
    "CX": "AUD",
    "CY": "EUR",
    "CZ": "CZK",
    "DE": "EUR",
    "DG": "USD",
    "DJ": "DJF",
    "DK": "DKK",
    "DM": "XCD",
    "DO": "DOP",
    "DZ": "DZD",
    "EA": "EUR",
    "EC": "USD",
    "EE": "EUR",
    "EG": "EGP",
    "EH": "MAD",
    "ER": "ERN",
    "ES": "EUR",
    "ET": "ETB",
    "EU": "EUR",
    "FI": "EUR",
    "FJ": "FJD",
    "FK": "FKP",
    "FM": "USD",
    "FO": "DKK",
    "FR": "EUR",
    "FX": "EUR",
    "GA": "XAF",
    "GB": "GBP",
    "GD": "XCD",
    "GE": "GEL",
    "GF": "EUR",
    "GG": "GBP",
    "GH": "GHS",
    "GI": "GIP",
    "GL": "DKK",
    "GM": "GMD",
    "GN": "GNF",
    "GP": "EUR",
    "GQ": "XAF",
    "GR": "EUR",
    "GS": "GBP",
    "GT": "GTQ",
    "GU": "USD",
    "GW": "XOF",
    "GY": "GYD",
    "HK": "HKD",
    "HM": "AUD",
    "HN": "HNL",
    "HR": "HRK",
    "HT": "HTG",
    "HU": "HUF",
    "IC": "EUR",
    "ID": "IDR",
    "IE": "EUR",
    "IL": "ILS",
    "IM": "GBP",
    "IN": "INR",
    "IO": "USD",
    "IQ": "IQD",
    "IR": "IRR",
    "IS": "ISK",
    "IT": "EUR",
    "JE": "GBP",
    "JM": "JMD",
    "JO": "JOD",
    "JP": "JPY",
    "KE": "KES",
    "KG": "KGS",
    "KH": "USD",
    "KI": "AUD",
    "KM": "KMF",
    "KN": "XCD",
    "KP": "KPW",
    "KR": "KRW",
    "KW": "KWD",
    "KV": "EUR",
    "KY": "KYD",
    "KZ": "KZT",
    "LA": "LAK",
    "LB": "LBP",
    "LC": "XCD",
    "LI": "CHF",
    "LK": "LKR",
    "LR": "LRD",
    "LS": "LSL",
    "LT": "EUR",
    "LU": "EUR",
    "LV": "EUR",
    "LY": "LYD",
    "MA": "MAD",
    "MC": "EUR",
    "MD": "MDL",
    "ME": "EUR",
    "MF": "EUR",
    "MG": "MGA",
    "MH": "USD",
    "MK": "MKD",
    "ML": "XOF",
    "MM": "MMK",
    "MN": "MNT",
    "MO": "MOP",
    "MP": "USD",
    "MQ": "EUR",
    "MR": "MRO",
    "MS": "XCD",
    "MT": "EUR",
    "MU": "MUR",
    "MV": "MVR",
    "MW": "MWK",
    "MX": "MXN",
    "MY": "MYR",
    "MZ": "MZN",
    "NA": "NAD",
    "NC": "XPF",
    "NE": "XOF",
    "NF": "AUD",
    "NG": "NGN",
    "NI": "NIO",
    "NL": "EUR",
    "NO": "NOK",
    "NP": "NPR",
    "NR": "AUD",
    "NU": "NZD",
    "NZ": "NZD",
    "OM": "OMR",
    "PA": "PAB",
    "PE": "PEN",
    "PF": "XPF",
    "PG": "PGK",
    "PH": "PHP",
    "PK": "PKR",
    "PL": "PLN",
    "PM": "EUR",
    "PN": "NZD",
    "PR": "USD",
    "PS": "JOD",
    "PT": "EUR",
    "PW": "USD",
    "PY": "PYG",
    "QA": "QAR",
    "RE": "EUR",
    "RO": "RON",
    "RS": "RSD",
    "RU": "RUB",
    "RW": "RWF",
    "SA": "SAR",
    "SB": "SBD",
    "SC": "SCR",
    "SD": "SDG",
    "SE": "SEK",
    "SG": "SGD",
    "SH": "SHP",
    "SI": "EUR",
    "SJ": "NOK",
    "SK": "EUR",
    "SL": "SLL",
    "SM": "EUR",
    "SN": "XOF",
    "SO": "SOS",
    "SR": "SRD",
    "SS": "SSP",
    "ST": "STD",
    "SU": "RUB",
    "SV": "USD",
    "SX": "ANG",
    "SY": "SYP",
    "SZ": "SZL",
    "TA": "GBP",
    "TC": "USD",
    "TD": "XAF",
    "TF": "EUR",
    "TG": "XOF",
    "TH": "THB",
    "TJ": "TJS",
    "TK": "NZD",
    "TL": "USD",
    "TM": "TMT",
    "TN": "TND",
    "TO": "TOP",
    "TR": "TRY",
    "TT": "TTD",
    "TV": "AUD",
    "TW": "TWD",
    "TZ": "TZS",
    "UA": "UAH",
    "UG": "UGX",
    "UK": "GBP",
    "UM": "USD",
    "US": "USD",
    "UY": "UYU",
    "UZ": "UZS",
    "VA": "EUR",
    "VC": "XCD",
    "VE": "VES",
    "VG": "USD",
    "VI": "USD",
    "VN": "VND",
    "VU": "VUV",
    "WF": "XPF",
    "WS": "WST",
    "YE": "YER",
    "YT": "EUR",
    "ZA": "ZAR",
    "ZM": "ZMW",
    "ZW": "USD",
  };
}
